"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Arc(google.protobuf.message.Message):
    """稿件基本信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AID_FIELD_NUMBER: builtins.int
    VIDEOS_FIELD_NUMBER: builtins.int
    TYPE_ID_FIELD_NUMBER: builtins.int
    TYPE_NAME_FIELD_NUMBER: builtins.int
    COPYRIGHT_FIELD_NUMBER: builtins.int
    PIC_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    PUBDATE_FIELD_NUMBER: builtins.int
    CTIME_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    ACCESS_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    MISSION_ID_FIELD_NUMBER: builtins.int
    ORDER_ID_FIELD_NUMBER: builtins.int
    REDIRECT_URL_FIELD_NUMBER: builtins.int
    FORWARD_FIELD_NUMBER: builtins.int
    RIGHTS_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    STAT_FIELD_NUMBER: builtins.int
    REPORT_RESULT_FIELD_NUMBER: builtins.int
    DYNAMIC_FIELD_NUMBER: builtins.int
    FIRST_CID_FIELD_NUMBER: builtins.int
    DIMENSION_FIELD_NUMBER: builtins.int
    STAFF_INFO_FIELD_NUMBER: builtins.int
    SEASON_ID_FIELD_NUMBER: builtins.int
    ATTRIBUTE_V2_FIELD_NUMBER: builtins.int
    SEASON_THEME_FIELD_NUMBER: builtins.int
    SHORT_LINK_V2_FIELD_NUMBER: builtins.int
    UP_FROM_V2_FIELD_NUMBER: builtins.int
    FIRST_FRAME_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """稿件avid"""
    videos: builtins.int
    """稿件分P数"""
    type_id: builtins.int
    """分区id"""
    type_name: builtins.str
    """二级分区名"""
    copyright: builtins.int
    """稿件类型
    1:原创 2:转载
    """
    pic: builtins.str
    """稿件封面url"""
    title: builtins.str
    """稿件标题"""
    pubdate: builtins.int
    """稿件发布时间"""
    ctime: builtins.int
    """用户投稿时间"""
    desc: builtins.str
    """稿件简介"""
    state: builtins.int
    """稿件状态"""
    access: builtins.int
    """访问属性
    0:全部可见 10000:登录可见
    """
    attribute: builtins.int
    """属性位配置(现在无了)"""
    tag: builtins.str
    """空"""
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """空"""
    duration: builtins.int
    """稿件总时长(单位为秒)"""
    mission_id: builtins.int
    """参与的活动id"""
    order_id: builtins.int
    """绑定的商单id"""
    redirect_url: builtins.str
    """PGC稿件强制重定向url(如番剧、影视)"""
    forward: builtins.int
    """空"""
    @property
    def rights(self) -> global___Rights:
        """控制标志"""
    @property
    def author(self) -> global___Author:
        """UP主信息"""
    @property
    def stat(self) -> global___Stat:
        """状态数"""
    report_result: builtins.str
    """空"""
    dynamic: builtins.str
    """投稿时发送的动态内容"""
    first_cid: builtins.int
    """稿件1P cid"""
    @property
    def dimension(self) -> global___Dimension:
        """稿件1P 分辨率"""
    @property
    def staff_info(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StaffInfo]:
        """合作组成员列表"""
    season_id: builtins.int
    """UGC合集id"""
    attribute_v2: builtins.int
    """新版属性位配置(也没用)"""
    @property
    def season_theme(self) -> global___SeasonTheme:
        """"""
    short_link_v2: builtins.str
    """"""
    up_from_v2: builtins.int
    """"""
    first_frame: builtins.str
    """"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
        videos: builtins.int = ...,
        type_id: builtins.int = ...,
        type_name: builtins.str = ...,
        copyright: builtins.int = ...,
        pic: builtins.str = ...,
        title: builtins.str = ...,
        pubdate: builtins.int = ...,
        ctime: builtins.int = ...,
        desc: builtins.str = ...,
        state: builtins.int = ...,
        access: builtins.int = ...,
        attribute: builtins.int = ...,
        tag: builtins.str = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
        duration: builtins.int = ...,
        mission_id: builtins.int = ...,
        order_id: builtins.int = ...,
        redirect_url: builtins.str = ...,
        forward: builtins.int = ...,
        rights: global___Rights | None = ...,
        author: global___Author | None = ...,
        stat: global___Stat | None = ...,
        report_result: builtins.str = ...,
        dynamic: builtins.str = ...,
        first_cid: builtins.int = ...,
        dimension: global___Dimension | None = ...,
        staff_info: collections.abc.Iterable[global___StaffInfo] | None = ...,
        season_id: builtins.int = ...,
        attribute_v2: builtins.int = ...,
        season_theme: global___SeasonTheme | None = ...,
        short_link_v2: builtins.str = ...,
        up_from_v2: builtins.int = ...,
        first_frame: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["author", b"author", "dimension", b"dimension", "rights", b"rights", "season_theme", b"season_theme", "stat", b"stat"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access", b"access", "aid", b"aid", "attribute", b"attribute", "attribute_v2", b"attribute_v2", "author", b"author", "copyright", b"copyright", "ctime", b"ctime", "desc", b"desc", "dimension", b"dimension", "duration", b"duration", "dynamic", b"dynamic", "first_cid", b"first_cid", "first_frame", b"first_frame", "forward", b"forward", "mission_id", b"mission_id", "order_id", b"order_id", "pic", b"pic", "pubdate", b"pubdate", "redirect_url", b"redirect_url", "report_result", b"report_result", "rights", b"rights", "season_id", b"season_id", "season_theme", b"season_theme", "short_link_v2", b"short_link_v2", "staff_info", b"staff_info", "stat", b"stat", "state", b"state", "tag", b"tag", "tags", b"tags", "title", b"title", "type_id", b"type_id", "type_name", b"type_name", "up_from_v2", b"up_from_v2", "videos", b"videos"]) -> None: ...

global___Arc = Arc

@typing_extensions.final
class Author(google.protobuf.message.Message):
    """UP主信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """UP主mid"""
    name: builtins.str
    """UP主昵称"""
    face: builtins.str
    """UP主头像url"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        name: builtins.str = ...,
        face: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["face", b"face", "mid", b"mid", "name", b"name"]) -> None: ...

global___Author = Author

@typing_extensions.final
class Dimension(google.protobuf.message.Message):
    """分辨率"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WIDTH_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    ROTATE_FIELD_NUMBER: builtins.int
    width: builtins.int
    """宽度"""
    height: builtins.int
    """高度"""
    rotate: builtins.int
    """方向
    0:横屏 1:竖屏
    """
    def __init__(
        self,
        *,
        width: builtins.int = ...,
        height: builtins.int = ...,
        rotate: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["height", b"height", "rotate", b"rotate", "width", b"width"]) -> None: ...

global___Dimension = Dimension

@typing_extensions.final
class Page(google.protobuf.message.Message):
    """分P信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CID_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    PART_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    VID_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    WEBLINK_FIELD_NUMBER: builtins.int
    DIMENSION_FIELD_NUMBER: builtins.int
    FIRST_FRAME_FIELD_NUMBER: builtins.int
    cid: builtins.int
    """视频cid"""
    page: builtins.int
    """分P序号"""
    part: builtins.str
    """分P标题"""
    duration: builtins.int
    """分P时长(单位为秒)"""
    vid: builtins.str
    """外链vid"""
    desc: builtins.str
    """分P简介"""
    webLink: builtins.str
    """外链url"""
    @property
    def dimension(self) -> global___Dimension:
        """分P分辨率"""
    first_frame: builtins.str
    """"""
    def __init__(
        self,
        *,
        cid: builtins.int = ...,
        page: builtins.int = ...,
        part: builtins.str = ...,
        duration: builtins.int = ...,
        vid: builtins.str = ...,
        desc: builtins.str = ...,
        webLink: builtins.str = ...,
        dimension: global___Dimension | None = ...,
        first_frame: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dimension", b"dimension"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cid", b"cid", "desc", b"desc", "dimension", b"dimension", "duration", b"duration", "first_frame", b"first_frame", "from", b"from", "page", b"page", "part", b"part", "vid", b"vid", "webLink", b"webLink"]) -> None: ...

global___Page = Page

@typing_extensions.final
class Rights(google.protobuf.message.Message):
    """稿件控制标志"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BP_FIELD_NUMBER: builtins.int
    ELEC_FIELD_NUMBER: builtins.int
    DOWNLOAD_FIELD_NUMBER: builtins.int
    MOVIE_FIELD_NUMBER: builtins.int
    PAY_FIELD_NUMBER: builtins.int
    HD5_FIELD_NUMBER: builtins.int
    NO_REPRINT_FIELD_NUMBER: builtins.int
    AUTOPLAY_FIELD_NUMBER: builtins.int
    UGC_PAY_FIELD_NUMBER: builtins.int
    IS_COOPERATION_FIELD_NUMBER: builtins.int
    UGC_PAY_PREVIEW_FIELD_NUMBER: builtins.int
    NO_BACKGROUND_FIELD_NUMBER: builtins.int
    ARC_PAY_FIELD_NUMBER: builtins.int
    PAY_FREE_WATCH_FIELD_NUMBER: builtins.int
    bp: builtins.int
    """老版是否付费"""
    elec: builtins.int
    """允许充电"""
    download: builtins.int
    """允许下载"""
    movie: builtins.int
    """是否电影"""
    pay: builtins.int
    """PGC稿件需要付费"""
    hd5: builtins.int
    """是否高码率"""
    no_reprint: builtins.int
    """是否显示“禁止转载”标志"""
    autoplay: builtins.int
    """是否允许自动播放"""
    ugc_pay: builtins.int
    """UGC稿件需要付费(旧版)"""
    is_cooperation: builtins.int
    """是否联合投稿"""
    ugc_pay_preview: builtins.int
    """是否UGC付费预览"""
    no_background: builtins.int
    """是否禁止后台播放"""
    arc_pay: builtins.int
    """UGC稿件需要付费"""
    pay_free_watch: builtins.int
    """是否已付费可自由观看"""
    def __init__(
        self,
        *,
        bp: builtins.int = ...,
        elec: builtins.int = ...,
        download: builtins.int = ...,
        movie: builtins.int = ...,
        pay: builtins.int = ...,
        hd5: builtins.int = ...,
        no_reprint: builtins.int = ...,
        autoplay: builtins.int = ...,
        ugc_pay: builtins.int = ...,
        is_cooperation: builtins.int = ...,
        ugc_pay_preview: builtins.int = ...,
        no_background: builtins.int = ...,
        arc_pay: builtins.int = ...,
        pay_free_watch: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["arc_pay", b"arc_pay", "autoplay", b"autoplay", "bp", b"bp", "download", b"download", "elec", b"elec", "hd5", b"hd5", "is_cooperation", b"is_cooperation", "movie", b"movie", "no_background", b"no_background", "no_reprint", b"no_reprint", "pay", b"pay", "pay_free_watch", b"pay_free_watch", "ugc_pay", b"ugc_pay", "ugc_pay_preview", b"ugc_pay_preview"]) -> None: ...

global___Rights = Rights

@typing_extensions.final
class SeasonTheme(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BG_COLOR_FIELD_NUMBER: builtins.int
    SELECTED_BG_COLOR_FIELD_NUMBER: builtins.int
    TEXT_COLOR_FIELD_NUMBER: builtins.int
    bg_color: builtins.str
    """"""
    selected_bg_color: builtins.str
    """"""
    text_color: builtins.str
    """"""
    def __init__(
        self,
        *,
        bg_color: builtins.str = ...,
        selected_bg_color: builtins.str = ...,
        text_color: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_color", b"bg_color", "selected_bg_color", b"selected_bg_color", "text_color", b"text_color"]) -> None: ...

global___SeasonTheme = SeasonTheme

@typing_extensions.final
class StaffInfo(google.protobuf.message.Message):
    """合作成员信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """成员mid"""
    title: builtins.str
    """成员角色"""
    attribute: builtins.int
    """属性位
    0:普通 1:赞助商金色标志
    """
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        title: builtins.str = ...,
        attribute: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["attribute", b"attribute", "mid", b"mid", "title", b"title"]) -> None: ...

global___StaffInfo = StaffInfo

@typing_extensions.final
class Stat(google.protobuf.message.Message):
    """状态数"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AID_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    DANMAKU_FIELD_NUMBER: builtins.int
    REPLY_FIELD_NUMBER: builtins.int
    FAV_FIELD_NUMBER: builtins.int
    COIN_FIELD_NUMBER: builtins.int
    SHARE_FIELD_NUMBER: builtins.int
    NOW_RANK_FIELD_NUMBER: builtins.int
    HIS_RANK_FIELD_NUMBER: builtins.int
    LIKE_FIELD_NUMBER: builtins.int
    DISLIKE_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """稿件avid"""
    view: builtins.int
    """播放数(当屏蔽时为-1)"""
    danmaku: builtins.int
    """弹幕数"""
    reply: builtins.int
    """评论数"""
    fav: builtins.int
    """收藏数"""
    coin: builtins.int
    """投币数"""
    share: builtins.int
    """分享数"""
    now_rank: builtins.int
    """当前排名"""
    his_rank: builtins.int
    """历史最高排名"""
    like: builtins.int
    """点赞数"""
    dislike: builtins.int
    """点踩数(前端不可见故恒为0)"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
        view: builtins.int = ...,
        danmaku: builtins.int = ...,
        reply: builtins.int = ...,
        fav: builtins.int = ...,
        coin: builtins.int = ...,
        share: builtins.int = ...,
        now_rank: builtins.int = ...,
        his_rank: builtins.int = ...,
        like: builtins.int = ...,
        dislike: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "coin", b"coin", "danmaku", b"danmaku", "dislike", b"dislike", "fav", b"fav", "his_rank", b"his_rank", "like", b"like", "now_rank", b"now_rank", "reply", b"reply", "share", b"share", "view", b"view"]) -> None: ...

global___Stat = Stat



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from bilireq.grpc.protos.bilibili.broadcast.v1 import push_pb2 as bilibili_dot_broadcast_dot_v1_dot_push__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class PushStub(object):
    """Push
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.WatchMessage = channel.unary_stream(
                '/bilibili.broadcast.v1.Push/WatchMessage',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=bilibili_dot_broadcast_dot_v1_dot_push__pb2.PushMessageResp.FromString,
                )


class PushServicer(object):
    """Push
    """

    def WatchMessage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PushServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'WatchMessage': grpc.unary_stream_rpc_method_handler(
                    servicer.WatchMessage,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=bilibili_dot_broadcast_dot_v1_dot_push__pb2.PushMessageResp.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bilibili.broadcast.v1.Push', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Push(object):
    """Push
    """

    @staticmethod
    def WatchMessage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/bilibili.broadcast.v1.Push/WatchMessage',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            bilibili_dot_broadcast_dot_v1_dot_push__pb2.PushMessageResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _GT14Status:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _GT14StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_GT14Status.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    LT14: _GT14Status.ValueType  # 0
    """"""
    GE14: _GT14Status.ValueType  # 1
    """"""
    UNKNOWN_GT14: _GT14Status.ValueType  # 2
    """"""

class GT14Status(_GT14Status, metaclass=_GT14StatusEnumTypeWrapper):
    """"""

LT14: GT14Status.ValueType  # 0
""""""
GE14: GT14Status.ValueType  # 1
""""""
UNKNOWN_GT14: GT14Status.ValueType  # 2
""""""
global___GT14Status = GT14Status

class _NFTStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _NFTStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_NFTStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNDEFINED: _NFTStatus.ValueType  # 0
    """"""
    NORMAL: _NFTStatus.ValueType  # 1
    """"""
    DOING: _NFTStatus.ValueType  # 2
    """"""

class NFTStatus(_NFTStatus, metaclass=_NFTStatusEnumTypeWrapper):
    """"""

UNDEFINED: NFTStatus.ValueType  # 0
""""""
NORMAL: NFTStatus.ValueType  # 1
""""""
DOING: NFTStatus.ValueType  # 2
""""""
global___NFTStatus = NFTStatus

class _PolicyAgreeStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PolicyAgreeStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PolicyAgreeStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNSIGNED: _PolicyAgreeStatus.ValueType  # 0
    """"""
    ACCEPTED: _PolicyAgreeStatus.ValueType  # 1
    """"""
    EXPIRED: _PolicyAgreeStatus.ValueType  # 2
    """"""

class PolicyAgreeStatus(_PolicyAgreeStatus, metaclass=_PolicyAgreeStatusEnumTypeWrapper):
    """"""

UNSIGNED: PolicyAgreeStatus.ValueType  # 0
""""""
ACCEPTED: PolicyAgreeStatus.ValueType  # 1
""""""
EXPIRED: PolicyAgreeStatus.ValueType  # 2
""""""
global___PolicyAgreeStatus = PolicyAgreeStatus

class _PolicyType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PolicyTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PolicyType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN_POLICY: _PolicyType.ValueType  # 0
    """"""
    WALLET: _PolicyType.ValueType  # 1
    """"""
    SALE: _PolicyType.ValueType  # 2
    """"""

class PolicyType(_PolicyType, metaclass=_PolicyTypeEnumTypeWrapper):
    """"""

UNKNOWN_POLICY: PolicyType.ValueType  # 0
""""""
WALLET: PolicyType.ValueType  # 1
""""""
SALE: PolicyType.ValueType  # 2
""""""
global___PolicyType = PolicyType

@typing_extensions.final
class AgreePolicyReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___AgreePolicyReply = AgreePolicyReply

@typing_extensions.final
class AgreePolicyReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POLICY_TYPE_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    policy_type: global___PolicyType.ValueType
    """"""
    version: builtins.str
    """"""
    def __init__(
        self,
        *,
        policy_type: global___PolicyType.ValueType = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["policy_type", b"policy_type", "version", b"version"]) -> None: ...

global___AgreePolicyReq = AgreePolicyReq

@typing_extensions.final
class BasicInfoReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CUSTOMER_SERVICE_URL_FIELD_NUMBER: builtins.int
    AGREEMENT_URL_FIELD_NUMBER: builtins.int
    PRIVACY_URL_FIELD_NUMBER: builtins.int
    LINKS_FIELD_NUMBER: builtins.int
    customer_service_url: builtins.str
    """"""
    agreement_url: builtins.str
    """"""
    privacy_url: builtins.str
    """"""
    @property
    def links(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Link]:
        """"""
    def __init__(
        self,
        *,
        customer_service_url: builtins.str = ...,
        agreement_url: builtins.str = ...,
        privacy_url: builtins.str = ...,
        links: collections.abc.Iterable[global___Link] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["agreement_url", b"agreement_url", "customer_service_url", b"customer_service_url", "links", b"links", "privacy_url", b"privacy_url"]) -> None: ...

global___BasicInfoReply = BasicInfoReply

@typing_extensions.final
class BasicInfoReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mid", b"mid"]) -> None: ...

global___BasicInfoReq = BasicInfoReq

@typing_extensions.final
class Display(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BG_THEME_LIGHT_FIELD_NUMBER: builtins.int
    BG_THEME_NIGHT_FIELD_NUMBER: builtins.int
    NFT_POSTER_FIELD_NUMBER: builtins.int
    NFT_RAW_FIELD_NUMBER: builtins.int
    bg_theme_light: builtins.str
    """"""
    bg_theme_night: builtins.str
    """"""
    nft_poster: builtins.str
    """"""
    nft_raw: builtins.str
    """"""
    def __init__(
        self,
        *,
        bg_theme_light: builtins.str = ...,
        bg_theme_night: builtins.str = ...,
        nft_poster: builtins.str = ...,
        nft_raw: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_theme_light", b"bg_theme_light", "bg_theme_night", b"bg_theme_night", "nft_poster", b"nft_poster", "nft_raw", b"nft_raw"]) -> None: ...

global___Display = Display

@typing_extensions.final
class GetLastPolicyReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHORT_DESC_FIELD_NUMBER: builtins.int
    DETAIL_JUMP_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    short_desc: builtins.str
    """"""
    detail_jump: builtins.str
    """"""
    version: builtins.str
    """"""
    def __init__(
        self,
        *,
        short_desc: builtins.str = ...,
        detail_jump: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["detail_jump", b"detail_jump", "short_desc", b"short_desc", "version", b"version"]) -> None: ...

global___GetLastPolicyReply = GetLastPolicyReply

@typing_extensions.final
class GetLastPolicyReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POLICY_TYPE_FIELD_NUMBER: builtins.int
    policy_type: global___PolicyType.ValueType
    """"""
    def __init__(
        self,
        *,
        policy_type: global___PolicyType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["policy_type", b"policy_type"]) -> None: ...

global___GetLastPolicyReq = GetLastPolicyReq

@typing_extensions.final
class GetUserInfoReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ADDRESS_FIELD_NUMBER: builtins.int
    AVATAR_URL_FIELD_NUMBER: builtins.int
    HELP_URL_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""
    name: builtins.str
    """"""
    address: builtins.str
    """"""
    avatar_url: builtins.str
    """"""
    help_url: builtins.str
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        name: builtins.str = ...,
        address: builtins.str = ...,
        avatar_url: builtins.str = ...,
        help_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["address", b"address", "avatar_url", b"avatar_url", "help_url", b"help_url", "mid", b"mid", "name", b"name"]) -> None: ...

global___GetUserInfoReply = GetUserInfoReply

@typing_extensions.final
class GetUserInfoReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mid", b"mid"]) -> None: ...

global___GetUserInfoReq = GetUserInfoReq

@typing_extensions.final
class Link(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    LINK_URL_FIELD_NUMBER: builtins.int
    TRACK_EVENT_ID_FIELD_NUMBER: builtins.int
    name: builtins.str
    """"""
    link_url: builtins.str
    """"""
    track_event_id: builtins.str
    """"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        link_url: builtins.str = ...,
        track_event_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["link_url", b"link_url", "name", b"name", "track_event_id", b"track_event_id"]) -> None: ...

global___Link = Link

@typing_extensions.final
class ListNFTByMidReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NFTS_FIELD_NUMBER: builtins.int
    ANCHOR_ID_FIELD_NUMBER: builtins.int
    END_FIELD_NUMBER: builtins.int
    @property
    def nfts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NFT]:
        """"""
    anchor_id: builtins.int
    """"""
    end: builtins.bool
    """"""
    def __init__(
        self,
        *,
        nfts: collections.abc.Iterable[global___NFT] | None = ...,
        anchor_id: builtins.int = ...,
        end: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["anchor_id", b"anchor_id", "end", b"end", "nfts", b"nfts"]) -> None: ...

global___ListNFTByMidReply = ListNFTByMidReply

@typing_extensions.final
class ListNFTByMidReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    CATEGORY_FIELD_NUMBER: builtins.int
    BIZ_TYPE_FIELD_NUMBER: builtins.int
    ANCHOR_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""
    category: builtins.str
    """"""
    biz_type: builtins.str
    """"""
    anchor_id: builtins.int
    """"""
    page_size: builtins.int
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        category: builtins.str = ...,
        biz_type: builtins.str = ...,
        anchor_id: builtins.int = ...,
        page_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["anchor_id", b"anchor_id", "biz_type", b"biz_type", "category", b"category", "mid", b"mid", "page_size", b"page_size"]) -> None: ...

global___ListNFTByMidReq = ListNFTByMidReq

@typing_extensions.final
class ListOrderByMidReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORDERS_FIELD_NUMBER: builtins.int
    ANCHOR_ID_FIELD_NUMBER: builtins.int
    END_FIELD_NUMBER: builtins.int
    @property
    def orders(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Order]:
        """"""
    anchor_id: builtins.int
    """"""
    end: builtins.bool
    """"""
    def __init__(
        self,
        *,
        orders: collections.abc.Iterable[global___Order] | None = ...,
        anchor_id: builtins.int = ...,
        end: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["anchor_id", b"anchor_id", "end", b"end", "orders", b"orders"]) -> None: ...

global___ListOrderByMidReply = ListOrderByMidReply

@typing_extensions.final
class ListOrderByMidReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    ANCHOR_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""
    anchor_id: builtins.int
    """"""
    page_size: builtins.int
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        anchor_id: builtins.int = ...,
        page_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["anchor_id", b"anchor_id", "mid", b"mid", "page_size", b"page_size"]) -> None: ...

global___ListOrderByMidReq = ListOrderByMidReq

@typing_extensions.final
class NFT(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NFT_ID_FIELD_NUMBER: builtins.int
    ITEM_NAME_FIELD_NUMBER: builtins.int
    SERIAL_NUMBER_FIELD_NUMBER: builtins.int
    ISSUER_FIELD_NUMBER: builtins.int
    DISPLAY_FIELD_NUMBER: builtins.int
    DETAIL_URL_FIELD_NUMBER: builtins.int
    NFT_STATUS_FIELD_NUMBER: builtins.int
    ITEM_ID_FIELD_NUMBER: builtins.int
    nft_id: builtins.str
    """"""
    item_name: builtins.str
    """"""
    serial_number: builtins.str
    """"""
    issuer: builtins.str
    """"""
    @property
    def display(self) -> global___Display:
        """"""
    detail_url: builtins.str
    """"""
    nft_status: global___NFTStatus.ValueType
    """"""
    item_id: builtins.int
    """"""
    def __init__(
        self,
        *,
        nft_id: builtins.str = ...,
        item_name: builtins.str = ...,
        serial_number: builtins.str = ...,
        issuer: builtins.str = ...,
        display: global___Display | None = ...,
        detail_url: builtins.str = ...,
        nft_status: global___NFTStatus.ValueType = ...,
        item_id: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["display", b"display"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["detail_url", b"detail_url", "display", b"display", "issuer", b"issuer", "item_id", b"item_id", "item_name", b"item_name", "nft_id", b"nft_id", "nft_status", b"nft_status", "serial_number", b"serial_number"]) -> None: ...

global___NFT = NFT

@typing_extensions.final
class Order(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEM_NAME_FIELD_NUMBER: builtins.int
    SERIAL_NUMBER_FIELD_NUMBER: builtins.int
    TX_HASH_FIELD_NUMBER: builtins.int
    TX_TIME_FIELD_NUMBER: builtins.int
    ISSUER_FIELD_NUMBER: builtins.int
    ISSUE_TIME_FIELD_NUMBER: builtins.int
    TOKEN_ID_FIELD_NUMBER: builtins.int
    DISPLAY_FIELD_NUMBER: builtins.int
    CONTRACT_ADDRESS_FIELD_NUMBER: builtins.int
    HASH_JUMP_FIELD_NUMBER: builtins.int
    CONTRACT_JUMP_FIELD_NUMBER: builtins.int
    DISABLE_BROWSER_JUMP_FIELD_NUMBER: builtins.int
    item_name: builtins.str
    """"""
    serial_number: builtins.str
    """"""
    tx_hash: builtins.str
    """"""
    tx_time: builtins.str
    """"""
    issuer: builtins.str
    """"""
    issue_time: builtins.str
    """"""
    token_id: builtins.str
    """"""
    @property
    def display(self) -> global___Display:
        """"""
    contract_address: builtins.str
    """"""
    hash_jump: builtins.str
    """"""
    contract_jump: builtins.str
    """"""
    disable_browser_jump: builtins.bool
    """"""
    def __init__(
        self,
        *,
        item_name: builtins.str = ...,
        serial_number: builtins.str = ...,
        tx_hash: builtins.str = ...,
        tx_time: builtins.str = ...,
        issuer: builtins.str = ...,
        issue_time: builtins.str = ...,
        token_id: builtins.str = ...,
        display: global___Display | None = ...,
        contract_address: builtins.str = ...,
        hash_jump: builtins.str = ...,
        contract_jump: builtins.str = ...,
        disable_browser_jump: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["display", b"display"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["contract_address", b"contract_address", "contract_jump", b"contract_jump", "disable_browser_jump", b"disable_browser_jump", "display", b"display", "hash_jump", b"hash_jump", "issue_time", b"issue_time", "issuer", b"issuer", "item_name", b"item_name", "serial_number", b"serial_number", "token_id", b"token_id", "tx_hash", b"tx_hash", "tx_time", b"tx_time"]) -> None: ...

global___Order = Order

@typing_extensions.final
class UserCheckReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POLICY_STATUS_FIELD_NUMBER: builtins.int
    GT14_FIELD_NUMBER: builtins.int
    policy_status: builtins.int
    """"""
    gt14: builtins.int
    """"""
    def __init__(
        self,
        *,
        policy_status: builtins.int = ...,
        gt14: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["gt14", b"gt14", "policy_status", b"policy_status"]) -> None: ...

global___UserCheckReply = UserCheckReply

@typing_extensions.final
class UserCheckReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    POLICY_TYPE_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""
    policy_type: builtins.int
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        policy_type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mid", b"mid", "policy_type", b"policy_type"]) -> None: ...

global___UserCheckReq = UserCheckReq



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/broadcast/message/main/resource.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.bilibili/broadcast/message/main/resource.proto\x12\x1f\x62ilibili.broadcast.message.main\x1a\x1bgoogle/protobuf/empty.proto\"\\\n\x10TopActivityReply\x12:\n\x06online\x18\x01 \x01(\x0b\x32*.bilibili.broadcast.message.main.TopOnline\x12\x0c\n\x04hash\x18\x02 \x01(\t\"\xdc\x01\n\tTopOnline\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0c\n\x04icon\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x11\n\tunique_id\x18\x04 \x01(\t\x12\x39\n\x07\x61nimate\x18\x05 \x01(\x0b\x32(.bilibili.broadcast.message.main.Animate\x12\x38\n\x07red_dot\x18\x06 \x01(\x0b\x32\'.bilibili.broadcast.message.main.RedDot\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x10\n\x08interval\x18\x08 \x01(\x03\"@\n\x07\x41nimate\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\x0c\n\x04json\x18\x02 \x01(\t\x12\x0b\n\x03svg\x18\x03 \x01(\t\x12\x0c\n\x04loop\x18\x04 \x01(\x05\"&\n\x06RedDot\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0e\n\x06number\x18\x02 \x01(\x05\x32\x66\n\x08Resource\x12Z\n\x0bTopActivity\x12\x16.google.protobuf.Empty\x1a\x31.bilibili.broadcast.message.main.TopActivityReply0\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.broadcast.message.main.resource_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TOPACTIVITYREPLY._serialized_start=112
  _TOPACTIVITYREPLY._serialized_end=204
  _TOPONLINE._serialized_start=207
  _TOPONLINE._serialized_end=427
  _ANIMATE._serialized_start=429
  _ANIMATE._serialized_end=493
  _REDDOT._serialized_start=495
  _REDDOT._serialized_end=533
  _RESOURCE._serialized_start=535
  _RESOURCE._serialized_end=637
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from bilireq.grpc.protos.bilibili.pgc.service.premiere.v1 import premiere_pb2 as bilibili_dot_pgc_dot_service_dot_premiere_dot_v1_dot_premiere__pb2


class PremiereStub(object):
    """首播服务
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Status = channel.unary_unary(
                '/bilibili.pgc.service.premiere.v1.Premiere/Status',
                request_serializer=bilibili_dot_pgc_dot_service_dot_premiere_dot_v1_dot_premiere__pb2.PremiereStatusReq.SerializeToString,
                response_deserializer=bilibili_dot_pgc_dot_service_dot_premiere_dot_v1_dot_premiere__pb2.PremiereStatusReply.FromString,
                )


class PremiereServicer(object):
    """首播服务
    """

    def Status(self, request, context):
        """获取首播状态
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PremiereServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Status': grpc.unary_unary_rpc_method_handler(
                    servicer.Status,
                    request_deserializer=bilibili_dot_pgc_dot_service_dot_premiere_dot_v1_dot_premiere__pb2.PremiereStatusReq.FromString,
                    response_serializer=bilibili_dot_pgc_dot_service_dot_premiere_dot_v1_dot_premiere__pb2.PremiereStatusReply.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bilibili.pgc.service.premiere.v1.Premiere', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Premiere(object):
    """首播服务
    """

    @staticmethod
    def Status(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.pgc.service.premiere.v1.Premiere/Status',
            bilibili_dot_pgc_dot_service_dot_premiere_dot_v1_dot_premiere__pb2.PremiereStatusReq.SerializeToString,
            bilibili_dot_pgc_dot_service_dot_premiere_dot_v1_dot_premiere__pb2.PremiereStatusReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from bilireq.grpc.protos.bilibili.app.resource.privacy.v1 import api_pb2 as bilibili_dot_app_dot_resource_dot_privacy_dot_v1_dot_api__pb2


class PrivacyStub(object):
    """隐私
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.PrivacyConfig = channel.unary_unary(
                '/bilibili.app.resource.privacy.v1.Privacy/PrivacyConfig',
                request_serializer=bilibili_dot_app_dot_resource_dot_privacy_dot_v1_dot_api__pb2.NoArgRequest.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_resource_dot_privacy_dot_v1_dot_api__pb2.PrivacyConfigReply.FromString,
                )
        self.SetPrivacyConfig = channel.unary_unary(
                '/bilibili.app.resource.privacy.v1.Privacy/SetPrivacyConfig',
                request_serializer=bilibili_dot_app_dot_resource_dot_privacy_dot_v1_dot_api__pb2.SetPrivacyConfigRequest.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_resource_dot_privacy_dot_v1_dot_api__pb2.NoReply.FromString,
                )


class PrivacyServicer(object):
    """隐私
    """

    def PrivacyConfig(self, request, context):
        """获取隐私设置
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetPrivacyConfig(self, request, context):
        """修改隐私设置
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PrivacyServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'PrivacyConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.PrivacyConfig,
                    request_deserializer=bilibili_dot_app_dot_resource_dot_privacy_dot_v1_dot_api__pb2.NoArgRequest.FromString,
                    response_serializer=bilibili_dot_app_dot_resource_dot_privacy_dot_v1_dot_api__pb2.PrivacyConfigReply.SerializeToString,
            ),
            'SetPrivacyConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.SetPrivacyConfig,
                    request_deserializer=bilibili_dot_app_dot_resource_dot_privacy_dot_v1_dot_api__pb2.SetPrivacyConfigRequest.FromString,
                    response_serializer=bilibili_dot_app_dot_resource_dot_privacy_dot_v1_dot_api__pb2.NoReply.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bilibili.app.resource.privacy.v1.Privacy', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Privacy(object):
    """隐私
    """

    @staticmethod
    def PrivacyConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.resource.privacy.v1.Privacy/PrivacyConfig',
            bilibili_dot_app_dot_resource_dot_privacy_dot_v1_dot_api__pb2.NoArgRequest.SerializeToString,
            bilibili_dot_app_dot_resource_dot_privacy_dot_v1_dot_api__pb2.PrivacyConfigReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetPrivacyConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.resource.privacy.v1.Privacy/SetPrivacyConfig',
            bilibili_dot_app_dot_resource_dot_privacy_dot_v1_dot_api__pb2.SetPrivacyConfigRequest.SerializeToString,
            bilibili_dot_app_dot_resource_dot_privacy_dot_v1_dot_api__pb2.NoReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/broadcast/message/editor/notify.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.bilibili/broadcast/message/editor/notify.proto\x12!bilibili.broadcast.message.editor\x1a\x1bgoogle/protobuf/empty.proto\"\xa6\x01\n\x06Notify\x12\x0e\n\x06msg_id\x18\x01 \x01(\x03\x12\x10\n\x08msg_type\x18\x02 \x01(\x05\x12\x14\n\x0creceiver_uid\x18\x03 \x01(\x03\x12\x15\n\rreceiver_type\x18\x04 \x01(\x05\x12\x15\n\rstory_version\x18\x05 \x01(\x03\x12\x0f\n\x07op_hash\x18\x06 \x01(\x03\x12\x11\n\top_sender\x18\x07 \x01(\x03\x12\x12\n\nop_content\x18\x08 \x01(\t2i\n\x0fOperationNotify\x12V\n\x0fOperationNotify\x12\x16.google.protobuf.Empty\x1a).bilibili.broadcast.message.editor.Notify0\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.broadcast.message.editor.notify_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _NOTIFY._serialized_start=115
  _NOTIFY._serialized_end=281
  _OPERATIONNOTIFY._serialized_start=283
  _OPERATIONNOTIFY._serialized_end=388
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/app/show/popular/v1/popular.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.app.card.v1 import card_pb2 as bilibili_dot_app_dot_card_dot_v1_dot_card__pb2
from bilireq.grpc.protos.bilibili.app.archive.middleware.v1 import preload_pb2 as bilibili_dot_app_dot_archive_dot_middleware_dot_v1_dot_preload__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*bilibili/app/show/popular/v1/popular.proto\x12\x14\x62ilibili.app.show.v1\x1a\x1f\x62ilibili/app/card/v1/card.proto\x1a\x30\x62ilibili/app/archive/middleware/v1/preload.proto\"@\n\x06\x42ubble\x12\x16\n\x0e\x62ubble_content\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x05\x12\r\n\x05stime\x18\x03 \x01(\x03\"\xf5\x01\n\x06\x43onfig\x12\x12\n\nitem_title\x18\x01 \x01(\t\x12\x13\n\x0b\x62ottom_text\x18\x02 \x01(\t\x12\x19\n\x11\x62ottom_text_cover\x18\x03 \x01(\t\x12\x17\n\x0f\x62ottom_text_url\x18\x04 \x01(\t\x12\x35\n\ttop_items\x18\x05 \x03(\x0b\x32\".bilibili.app.show.v1.EntranceShow\x12\x12\n\nhead_image\x18\x06 \x01(\t\x12\x36\n\npage_items\x18\x07 \x03(\x0b\x32\".bilibili.app.show.v1.EntranceShow\x12\x0b\n\x03hit\x18\x08 \x01(\x05\"\xb8\x01\n\x0c\x45ntranceShow\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x11\n\tmodule_id\x18\x03 \x01(\t\x12\x0b\n\x03uri\x18\x04 \x01(\t\x12,\n\x06\x62ubble\x18\x05 \x01(\x0b\x32\x1c.bilibili.app.show.v1.Bubble\x12\x13\n\x0b\x65ntrance_id\x18\x06 \x01(\x03\x12\x11\n\ttop_photo\x18\x07 \x01(\t\x12\x15\n\rentrance_type\x18\x08 \x01(\x05\"t\n\x0cPopularReply\x12)\n\x05items\x18\x01 \x03(\x0b\x32\x1a.bilibili.app.card.v1.Card\x12,\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x1c.bilibili.app.show.v1.Config\x12\x0b\n\x03ver\x18\x03 \x01(\t\"\xc3\x02\n\x10PopularResultReq\x12\x0b\n\x03idx\x18\x01 \x01(\x03\x12\x13\n\x0blogin_event\x18\x02 \x01(\x05\x12\n\n\x02qn\x18\x03 \x01(\x05\x12\r\n\x05\x66nver\x18\x04 \x01(\x05\x12\r\n\x05\x66nval\x18\x05 \x01(\x05\x12\x12\n\nforce_host\x18\x06 \x01(\x05\x12\r\n\x05\x66ourk\x18\x07 \x01(\x05\x12\r\n\x05spmid\x18\x08 \x01(\t\x12\x12\n\nlast_param\x18\t \x01(\t\x12\x0b\n\x03ver\x18\n \x01(\t\x12\x13\n\x0b\x65ntrance_id\x18\x0b \x01(\x03\x12\x14\n\x0clocation_ids\x18\x0c \x01(\t\x12\x11\n\tsource_id\x18\r \x01(\x05\x12\r\n\x05\x66lush\x18\x0e \x01(\x05\x12\x43\n\x0bplayer_args\x18\x0f \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs2^\n\x07Popular\x12S\n\x05Index\x12&.bilibili.app.show.v1.PopularResultReq\x1a\".bilibili.app.show.v1.PopularReplyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.show.popular.v1.popular_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BUBBLE._serialized_start=151
  _BUBBLE._serialized_end=215
  _CONFIG._serialized_start=218
  _CONFIG._serialized_end=463
  _ENTRANCESHOW._serialized_start=466
  _ENTRANCESHOW._serialized_end=650
  _POPULARREPLY._serialized_start=652
  _POPULARREPLY._serialized_end=768
  _POPULARRESULTREQ._serialized_start=771
  _POPULARRESULTREQ._serialized_end=1094
  _POPULAR._serialized_start=1096
  _POPULAR._serialized_end=1190
# @@protoc_insertion_point(module_scope)



from typing import Union
from bilireq.utils import get, post
from bilireq.utils.av_bv import VideoID


async def get_video_base_info(video_id: Union[int, str]):
    """获取哔哩哔哩视频基本信息"""
    url = "https://api.bilibili.com/x/web-interface/view"
    vid = VideoID(video_id)
    params = {"aid": vid.aid}
    return await get(url, params=params)


async def get_video_share(video_id: Union[int, str]):
    """模拟移动端哔哩哔哩视频分享点击"""
    vid = VideoID(video_id)
    body = {
        "build": "6060600",
        "buvid": "0",
        "oid": vid.aid,
        "platform": "android",
        "share_channel": "QQ",
        "share_id": "main.ugc-video-detail.0.0.pv",
        "share_mode": "7",
    }
    headers = {"Content-Type": "application/x-www-form-urlencoded"}
    url = "https://api.biliapi.net/x/share/click"
    return await post(url, data=body, headers=headers)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/app/space/v1/space.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!bilibili/app/space/v1/space.proto\x12\x15\x62ilibili.app.space.v1\"\xc5\x01\n\x0c\x41rchiveReply\x12\x33\n\x04item\x18\x01 \x03(\x0b\x32%.bilibili.app.space.v1.BiliSpaceVideo\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\x12>\n\x0f\x65pisodic_button\x18\x03 \x01(\x0b\x32%.bilibili.app.space.v1.EpisodicButton\x12\x31\n\x05order\x18\x04 \x03(\x0b\x32\".bilibili.app.space.v1.OrderConfig\"A\n\nArchiveReq\x12\x0c\n\x04vmid\x18\x01 \x01(\x03\x12\n\n\x02pn\x18\x02 \x01(\x05\x12\n\n\x02ps\x18\x03 \x01(\x05\x12\r\n\x05order\x18\x04 \x01(\t\"\xb1\x01\n\x05\x42\x61\x64ge\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x12\n\ntext_color\x18\x02 \x01(\t\x12\x18\n\x10text_color_night\x18\x03 \x01(\t\x12\x10\n\x08\x62g_color\x18\x04 \x01(\t\x12\x16\n\x0e\x62g_color_night\x18\x05 \x01(\t\x12\x14\n\x0c\x62order_color\x18\x06 \x01(\t\x12\x1a\n\x12\x62order_color_night\x18\x07 \x01(\t\x12\x10\n\x08\x62g_style\x18\x08 \x01(\x05\"\xcb\x02\n\x0e\x42iliSpaceVideo\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05tname\x18\x02 \x01(\t\x12\x10\n\x08\x64uration\x18\x03 \x01(\x03\x12\r\n\x05\x63over\x18\x04 \x01(\t\x12\x0b\n\x03uri\x18\x05 \x01(\t\x12\r\n\x05param\x18\x06 \x01(\t\x12\x0f\n\x07\x64\x61nmaku\x18\x07 \x01(\t\x12\x0c\n\x04play\x18\x08 \x01(\x05\x12\r\n\x05\x63time\x18\t \x01(\x03\x12\r\n\x05state\x18\n \x01(\x08\x12\x12\n\nis_popular\x18\x0b \x01(\x08\x12,\n\x06\x62\x61\x64ges\x18\x0c \x03(\x0b\x32\x1c.bilibili.app.space.v1.Badge\x12\x13\n\x0b\x63over_right\x18\r \x01(\t\x12\x0c\n\x04\x62vid\x18\x0e \x01(\t\x12\x11\n\tis_steins\x18\x0f \x01(\x08\x12\x11\n\tis_ugcpay\x18\x10 \x01(\x08\x12\x16\n\x0eis_cooperation\x18\x11 \x01(\x08\"+\n\x0e\x45pisodicButton\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\"+\n\x0bOrderConfig\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t2Z\n\x05Space\x12Q\n\x07\x41rchive\x12!.bilibili.app.space.v1.ArchiveReq\x1a#.bilibili.app.space.v1.ArchiveReplyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.space.v1.space_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ARCHIVEREPLY._serialized_start=61
  _ARCHIVEREPLY._serialized_end=258
  _ARCHIVEREQ._serialized_start=260
  _ARCHIVEREQ._serialized_end=325
  _BADGE._serialized_start=328
  _BADGE._serialized_end=505
  _BILISPACEVIDEO._serialized_start=508
  _BILISPACEVIDEO._serialized_end=839
  _EPISODICBUTTON._serialized_start=841
  _EPISODICBUTTON._serialized_end=884
  _ORDERCONFIG._serialized_start=886
  _ORDERCONFIG._serialized_end=929
  _SPACE._serialized_start=931
  _SPACE._serialized_end=1021
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/ad/v1/ad.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x62ilibili/ad/v1/ad.proto\x12\x0e\x62ilibili.ad.v1\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\x8f\x02\n\x12\x41\x64\x41utoPlayVideoDto\x12\x0c\n\x04\x61vid\x18\x01 \x01(\x03\x12\x0b\n\x03\x63id\x18\x02 \x01(\x03\x12\x0c\n\x04page\x18\x03 \x01(\x03\x12\x0c\n\x04\x66rom\x18\x04 \x01(\t\x12\x0b\n\x03url\x18\x05 \x01(\t\x12\r\n\x05\x63over\x18\x06 \x01(\t\x12\x11\n\tauto_play\x18\x07 \x01(\x08\x12\x15\n\rbtn_dyc_color\x18\x08 \x01(\x08\x12\x14\n\x0c\x62tn_dyc_time\x18\t \x01(\x05\x12\x0e\n\x06\x62iz_id\x18\n \x01(\x03\x12\x15\n\rprocess0_urls\x18\x0b \x03(\t\x12\x14\n\x0cplay_3s_urls\x18\x0c \x03(\t\x12\x14\n\x0cplay_5s_urls\x18\r \x03(\t\x12\x13\n\x0borientation\x18\x0e \x01(\x05\"\x8a\x02\n\x11\x41\x64\x42usinessMarkDto\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x12\n\ntext_color\x18\x03 \x01(\t\x12\x18\n\x10text_color_night\x18\x04 \x01(\t\x12\x10\n\x08\x62g_color\x18\x05 \x01(\t\x12\x16\n\x0e\x62g_color_night\x18\x06 \x01(\t\x12\x14\n\x0c\x62order_color\x18\x07 \x01(\t\x12\x1a\n\x12\x62order_color_night\x18\x08 \x01(\t\x12\x0f\n\x07img_url\x18\t \x01(\t\x12\x12\n\nimg_height\x18\n \x01(\x05\x12\x11\n\timg_width\x18\x0b \x01(\x05\x12\x17\n\x0f\x62g_border_color\x18\x0c \x01(\t\"\xcc\x01\n\x0b\x41\x64\x42uttonDto\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x10\n\x08jump_url\x18\x03 \x01(\t\x12\x13\n\x0breport_urls\x18\x04 \x01(\t\x12\x18\n\x10\x64lsuc_callup_url\x18\x05 \x01(\t\x12\x0f\n\x07game_id\x18\x06 \x01(\x05\x12\x1a\n\x12game_monitor_param\x18\x07 \x01(\t\x12\x17\n\x0fgame_channel_id\x18\x08 \x01(\x05\x12\x1a\n\x12game_channel_extra\x18\t \x01(\t\"\xef\r\n\tAdCardDto\x12\x11\n\tcard_type\x18\x01 \x01(\x05\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\x12\x12\n\nextra_desc\x18\x04 \x01(\t\x12\x11\n\tlong_desc\x18\x05 \x01(\t\x12\x13\n\x0bshort_title\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x61nmu_title\x18\x07 \x01(\t\x12\x14\n\x0c\x64\x61nmu_height\x18\x08 \x01(\x05\x12\x13\n\x0b\x64\x61nmu_width\x18\t \x01(\x05\x12\x12\n\ndanmu_life\x18\n \x01(\x05\x12\x13\n\x0b\x64\x61nmu_begin\x18\x0b \x01(\x05\x12\x13\n\x0b\x64\x61nmu_color\x18\x0c \x01(\t\x12\x13\n\x0b\x64\x61nmu_h5url\x18\r \x01(\t\x12\x12\n\ndanmu_icon\x18\x0e \x01(\t\x12\x11\n\tfold_time\x18\x0f \x01(\x05\x12\x0e\n\x06\x61\x64_tag\x18\x10 \x01(\t\x12*\n\x06\x63overs\x18\x11 \x03(\x0b\x32\x1a.bilibili.ad.v1.AdCoverDto\x12\x10\n\x08jump_url\x18\x12 \x01(\t\x12%\n\x1dimax_landing_page_json_string\x18\x13 \x01(\t\x12\x12\n\ncallup_url\x18\x14 \x01(\t\x12\x15\n\runiversal_app\x18\x15 \x01(\t\x12\x11\n\tori_price\x18\x16 \x01(\t\x12\x11\n\tcur_price\x18\x17 \x01(\x05\x12\x12\n\nprice_desc\x18\x18 \x01(\t\x12\x14\n\x0cprice_symbol\x18\x19 \x01(\t\x12\x17\n\x0fgoods_cur_price\x18\x1a \x01(\t\x12\x17\n\x0fgoods_ori_price\x18\x1b \x01(\t\x12\'\n\x04good\x18\x1c \x01(\x0b\x32\x19.bilibili.ad.v1.AdGoodDto\x12\x0c\n\x04rank\x18\x1d \x01(\x05\x12\x11\n\thot_score\x18\x1e \x01(\x05\x12+\n\x06\x62utton\x18\x1f \x01(\x0b\x32\x1b.bilibili.ad.v1.AdButtonDto\x12\x12\n\nadver_logo\x18  \x01(\t\x12\x12\n\nadver_name\x18! \x01(\t\x12\x16\n\x0e\x61\x64ver_page_url\x18\" \x01(\t\x12\x15\n\rvideo_barrage\x18# \x03(\t\x12\x37\n\x0c\x61\x64_tag_style\x18$ \x01(\x0b\x32!.bilibili.ad.v1.AdBusinessMarkDto\x12\x31\n\x05video\x18% \x01(\x0b\x32\".bilibili.ad.v1.AdAutoPlayVideoDto\x12:\n\x0e\x66\x65\x65\x64\x62\x61\x63k_panel\x18& \x01(\x0b\x32\".bilibili.ad.v1.AdFeedbackPanelDto\x12\x11\n\tadver_mid\x18\' \x01(\x03\x12\x18\n\x10\x61\x64ver_account_id\x18( \x01(\x03\x12\x10\n\x08\x64uration\x18) \x01(\t\x12\x32\n\rquality_infos\x18* \x03(\x0b\x32\x1b.bilibili.ad.v1.QualityInfo\x12\x14\n\x0c\x64ynamic_text\x18+ \x01(\t\x12\'\n\x05\x61\x64ver\x18, \x01(\x0b\x32\x18.bilibili.ad.v1.AdverDto\x12\x13\n\x0bgrade_level\x18- \x01(\x05\x12\x1a\n\x12support_transition\x18. \x01(\x08\x12\x12\n\ntransition\x18/ \x01(\t\x12&\n\x1eunder_player_interaction_style\x18\x30 \x01(\x05\x12\x1c\n\x14imax_landing_page_v2\x18\x31 \x01(\t\x12\x35\n\x0esubcard_module\x18\x32 \x01(\x0b\x32\x1d.bilibili.ad.v1.SubCardModule\x12\x19\n\x11grade_denominator\x18\x33 \x01(\x05\x12\x12\n\nstar_level\x18\x34 \x01(\x05\x12*\n\x08\x62ulletin\x18\x35 \x01(\x0b\x32\x18.bilibili.ad.v1.Bulletin\x12\"\n\x04gift\x18\x36 \x01(\x0b\x32\x14.bilibili.ad.v1.Gift\x12\x11\n\tgame_tags\x18\x37 \x03(\t\x12\x17\n\x0fori_mark_hidden\x18\x38 \x01(\x05\x12\x17\n\x0fuse_multi_cover\x18\x39 \x01(\x08\x12\x36\n\x0fwx_program_info\x18: \x01(\x0b\x32\x1d.bilibili.ad.v1.WxProgramInfo\x12\x41\n\x15\x61ndroid_game_page_res\x18; \x01(\x0b\x32\".bilibili.ad.v1.AndroidGamePageRes\x12<\n\x12not_clickable_area\x18< \x01(\x0b\x32 .bilibili.ad.v1.NotClickableArea\x12\x33\n\rforward_reply\x18= \x01(\x0b\x32\x1c.bilibili.ad.v1.ForwardReply\"\xb5\t\n\x11\x41\x64\x43ontentExtraDto\x12\x0e\n\x06layout\x18\x01 \x01(\t\x12\x11\n\tshow_urls\x18\x02 \x03(\t\x12\x12\n\nclick_urls\x18\x03 \x03(\t\x12\x1c\n\x14\x64\x61nmu_list_show_urls\x18\x04 \x03(\t\x12\x1d\n\x15\x64\x61nmu_list_click_urls\x18\x05 \x03(\t\x12\x1e\n\x16\x64\x61nmu_detail_show_urls\x18\x06 \x03(\t\x12\x1e\n\x16\x64\x61nmu_trolley_add_urls\x18\x07 \x03(\t\x12\x15\n\ruse_ad_web_v2\x18\x08 \x01(\x08\x12\x16\n\x0eopen_whitelist\x18\t \x03(\t\x12\x39\n\x12\x64ownload_whitelist\x18\n \x01(\x0b\x32\x1d.bilibili.ad.v1.AppPackageDto\x12\'\n\x04\x63\x61rd\x18\x0b \x01(\x0b\x32\x19.bilibili.ad.v1.AdCardDto\x12\x13\n\x0breport_time\x18\x0c \x01(\x05\x12\x19\n\x11\x61ppstore_priority\x18\r \x01(\x05\x12\x12\n\nsales_type\x18\x0e \x01(\x05\x12\x1b\n\x13preload_landingpage\x18\x0f \x01(\x05\x12\x18\n\x10special_industry\x18\x10 \x01(\x08\x12\x1d\n\x15special_industry_tips\x18\x11 \x01(\t\x12\x1e\n\x16\x65nable_download_dialog\x18\x12 \x01(\x08\x12\x14\n\x0c\x65nable_share\x18\x13 \x01(\x08\x12\x1c\n\x14upzone_entrance_type\x18\x14 \x01(\x05\x12!\n\x19upzone_entrance_report_id\x18\x15 \x01(\x05\x12\x32\n\nshare_info\x18\x16 \x01(\x0b\x32\x1e.bilibili.ad.v1.AdShareInfoDto\x12\x17\n\x0ftopview_pic_url\x18\x17 \x01(\t\x12\x19\n\x11topview_video_url\x18\x18 \x01(\t\x12\x12\n\nclick_area\x18\x19 \x01(\x05\x12\x0f\n\x07shop_id\x18\x1a \x01(\x03\x12\x0e\n\x06up_mid\x18\x1b \x01(\x03\x12\x10\n\x08track_id\x18\x1c \x01(\t\x12\"\n\x1a\x65nable_store_direct_launch\x18\x1d \x01(\x05\x12\x12\n\nproduct_id\x18\x1e \x01(\x03\x12\x1a\n\x12\x65nable_double_jump\x18\x1f \x01(\x08\x12\x13\n\x0bshow1s_urls\x18  \x03(\t\x12\x15\n\rfrom_track_id\x18! \x01(\t\x12\x19\n\x11store_callup_card\x18\" \x01(\x08\x12\"\n\x1alandingpage_download_style\x18# \x01(\x05\x12\x1e\n\x16special_industry_style\x18$ \x01(\x05\x12\x17\n\x0f\x65nable_h5_alert\x18% \x01(\x08\x12\x1e\n\x16macro_replace_priority\x18& \x01(\x05\x12\x1c\n\x14\x66\x65\x65\x64\x62\x61\x63k_panel_style\x18\' \x01(\x05\x12\x14\n\x0c\x61ppstore_url\x18( \x01(\t\x12\x1a\n\x12\x65nable_h5_pre_load\x18) \x01(\x05\x12\x17\n\x0fh5_pre_load_url\x18* \x01(\t\x12\x18\n\x10\x63m_from_track_id\x18+ \x01(\t\"y\n\nAdCoverDto\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x0c\n\x04loop\x18\x02 \x01(\x05\x12\x10\n\x08jump_url\x18\x03 \x01(\t\x12\x13\n\x0breport_urls\x18\x04 \x03(\t\x12\x14\n\x0cimage_height\x18\x05 \x01(\x05\x12\x13\n\x0bimage_width\x18\x06 \x01(\x05\"\x8b\x02\n\x05\x41\x64\x44to\x12\x13\n\x0b\x63reative_id\x18\x01 \x01(\x03\x12\r\n\x05\x61\x64_cb\x18\x02 \x01(\t\x12\x30\n\x05\x65xtra\x18\x03 \x01(\x0b\x32!.bilibili.ad.v1.AdContentExtraDto\x12\x0f\n\x07\x63m_mark\x18\x04 \x01(\x05\x12\x13\n\x0btop_view_id\x18\x05 \x01(\x03\x12\x15\n\rcreative_type\x18\x06 \x01(\x05\x12\x11\n\tcard_type\x18\x07 \x01(\x05\x12\x16\n\x0e\x63reative_style\x18\x08 \x01(\x05\x12\r\n\x05is_ad\x18\t \x01(\x05\x12\x35\n\x10\x63reative_content\x18\n \x01(\x0b\x32\x1b.bilibili.ad.v1.CreativeDto\"\xb4\x01\n\x12\x41\x64\x46\x65\x65\x64\x62\x61\x63kPanelDto\x12\x17\n\x0fpanel_type_text\x18\x01 \x01(\t\x12G\n\x15\x66\x65\x65\x64\x62\x61\x63k_panel_detail\x18\x02 \x03(\x0b\x32(.bilibili.ad.v1.AdFeedbackPanelModuleDto\x12\r\n\x05toast\x18\x03 \x01(\t\x12\x15\n\ropen_rec_tips\x18\x04 \x01(\t\x12\x16\n\x0e\x63lose_rec_tips\x18\x05 \x01(\t\"\xc7\x01\n\x18\x41\x64\x46\x65\x65\x64\x62\x61\x63kPanelModuleDto\x12\x11\n\tmodule_id\x18\x01 \x01(\x05\x12\x10\n\x08icon_url\x18\x02 \x01(\t\x12\x11\n\tjump_type\x18\x03 \x01(\x05\x12\x10\n\x08jump_url\x18\x04 \x01(\t\x12\x0c\n\x04text\x18\x05 \x01(\t\x12\x41\n\x0fsecondary_panel\x18\x06 \x03(\x0b\x32(.bilibili.ad.v1.AdSecondFeedbackPanelDto\x12\x10\n\x08sub_text\x18\x07 \x01(\t\"N\n\tAdGoodDto\x12\x0f\n\x07item_id\x18\x01 \x01(\x03\x12\x0e\n\x06sku_id\x18\x02 \x01(\x03\x12\x0f\n\x07shop_id\x18\x03 \x01(\x03\x12\x0f\n\x07sku_num\x18\x04 \x01(\x03\"1\n\nAdOgvEpDto\x12\x0c\n\x04\x65pid\x18\x01 \x01(\x03\x12\x15\n\rhas_recommend\x18\x02 \x01(\x08\"Y\n\rAdsControlDto\x12\x11\n\thas_danmu\x18\x01 \x01(\x05\x12\x0c\n\x04\x63ids\x18\x02 \x03(\x03\x12\'\n\x03\x65ps\x18\x03 \x03(\x0b\x32\x1a.bilibili.ad.v1.AdOgvEpDto\";\n\x18\x41\x64SecondFeedbackPanelDto\x12\x11\n\treason_id\x18\x01 \x01(\x05\x12\x0c\n\x04text\x18\x02 \x01(\t\"D\n\x0e\x41\x64ShareInfoDto\x12\r\n\x05title\x18\x01 \x01(\t\x12\x10\n\x08subtitle\x18\x02 \x01(\t\x12\x11\n\timage_url\x18\x03 \x01(\t\"\x84\x01\n\x08\x41\x64verDto\x12\x10\n\x08\x61\x64ver_id\x18\x01 \x01(\x03\x12\x12\n\nadver_logo\x18\x02 \x01(\t\x12\x12\n\nadver_name\x18\x03 \x01(\t\x12\x12\n\nadver_type\x18\x04 \x01(\x05\x12\x16\n\x0e\x61\x64ver_page_url\x18\x05 \x01(\t\x12\x12\n\nadver_desc\x18\x06 \x01(\t\"\xee\x04\n\x12\x41ndroidGamePageRes\x12(\n\x07module1\x18\x01 \x01(\x0b\x32\x17.bilibili.ad.v1.Module1\x12(\n\x07module3\x18\x02 \x01(\x0b\x32\x17.bilibili.ad.v1.Module3\x12(\n\x07module4\x18\x03 \x01(\x0b\x32\x17.bilibili.ad.v1.Module4\x12(\n\x07module5\x18\x04 \x01(\x0b\x32\x17.bilibili.ad.v1.Module5\x12(\n\x07module6\x18\x05 \x01(\x0b\x32\x17.bilibili.ad.v1.Module6\x12(\n\x07module7\x18\x06 \x01(\x0b\x32\x17.bilibili.ad.v1.Module7\x12(\n\x07module8\x18\x07 \x01(\x0b\x32\x17.bilibili.ad.v1.Module8\x12(\n\x07module9\x18\x08 \x01(\x0b\x32\x17.bilibili.ad.v1.Module9\x12*\n\x08module10\x18\t \x01(\x0b\x32\x18.bilibili.ad.v1.Module10\x12*\n\x08module11\x18\n \x01(\x0b\x32\x18.bilibili.ad.v1.Module11\x12*\n\x08module12\x18\x0b \x01(\x0b\x32\x18.bilibili.ad.v1.Module12\x12*\n\x08module13\x18\x0c \x01(\x0b\x32\x18.bilibili.ad.v1.Module13\x12\x12\n\nmodule_seq\x18\r \x03(\x05\x12\x18\n\x10\x62\x61\x63kground_color\x18\x0e \x01(\t\x12*\n\x08module14\x18\x0f \x01(\x0b\x32\x18.bilibili.ad.v1.Module14\"(\n\nAndroidTag\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\x05\"\x87\x02\n\rAppPackageDto\x12\x0c\n\x04size\x18\x01 \x01(\x03\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x10\n\x08\x61pk_name\x18\x03 \x01(\t\x12\x0b\n\x03url\x18\x04 \x01(\t\x12\x10\n\x08\x62ili_url\x18\x05 \x01(\t\x12\x0b\n\x03md5\x18\x06 \x01(\t\x12\x0c\n\x04icon\x18\x07 \x01(\t\x12\x10\n\x08\x64\x65v_name\x18\x08 \x01(\t\x12\x10\n\x08\x61uth_url\x18\t \x01(\t\x12\x11\n\tauth_name\x18\n \x01(\t\x12\x0f\n\x07version\x18\x0b \x01(\t\x12\x13\n\x0bupdate_time\x18\x0c \x01(\t\x12\x14\n\x0cprivacy_name\x18\r \x01(\t\x12\x13\n\x0bprivacy_url\x18\x0e \x01(\t\"*\n\x08\x42ulletin\x12\x10\n\x08tag_text\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\"\x9f\x01\n\x07\x43omment\x12\x14\n\x0cgame_base_id\x18\x01 \x01(\x03\x12\x11\n\tuser_name\x18\x02 \x01(\t\x12\x11\n\tuser_face\x18\x03 \x01(\t\x12\x12\n\nuser_level\x18\x04 \x01(\x05\x12\x12\n\ncomment_no\x18\x05 \x01(\t\x12\r\n\x05grade\x18\x06 \x01(\x05\x12\x0f\n\x07\x63ontent\x18\x07 \x01(\t\x12\x10\n\x08up_count\x18\x08 \x01(\x05\"\x83\x02\n\x0b\x43reativeDto\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x11\n\timage_url\x18\x03 \x01(\t\x12\x11\n\timage_md5\x18\x04 \x01(\t\x12\x0b\n\x03url\x18\x05 \x01(\t\x12\x11\n\tclick_url\x18\x06 \x01(\t\x12\x10\n\x08show_url\x18\x07 \x01(\t\x12\x10\n\x08video_id\x18\x08 \x01(\x03\x12\x15\n\rthumbnail_url\x18\t \x01(\t\x12\x19\n\x11thumbnail_url_md5\x18\n \x01(\t\x12\x10\n\x08logo_url\x18\x0b \x01(\t\x12\x10\n\x08logo_md5\x18\x0c \x01(\t\x12\x10\n\x08username\x18\r \x01(\t\"0\n\rCustomPlayUrl\x12\x11\n\tplay_time\x18\x01 \x01(\x05\x12\x0c\n\x04urls\x18\x02 \x03(\t\"\xcd\x01\n\x0c\x46orwardReply\x12\x12\n\ncomment_id\x18\x01 \x01(\x03\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x16\n\x0ehighlight_text\x18\x03 \x01(\t\x12\x1d\n\x15highlight_prefix_icon\x18\x04 \x01(\t\x12\x12\n\ncallup_url\x18\x05 \x01(\t\x12\x10\n\x08jump_url\x18\x06 \x01(\t\x12\x11\n\tjump_type\x18\x07 \x01(\x05\x12\x13\n\x0b\x61uthor_name\x18\x08 \x01(\t\x12\x13\n\x0b\x61uthor_icon\x18\t \x01(\t\"C\n\x04Gift\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\x12\n\nnight_icon\x18\x02 \x01(\t\x12\x0c\n\x04text\x18\x03 \x01(\t\x12\x0b\n\x03url\x18\x04 \x01(\t\"\xc7\x01\n\x0eIosGamePageRes\x12\x0c\n\x04logo\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nsub_titile\x18\x03 \x01(\t\x12\x11\n\timage_url\x18\x04 \x03(\t\x12\x0c\n\x04\x64\x65sc\x18\x05 \x01(\t\x12\x30\n\x0bgame_button\x18\x06 \x01(\x0b\x32\x1b.bilibili.ad.v1.AdButtonDto\x12\r\n\x05grade\x18\x07 \x01(\x01\x12\x10\n\x08rank_num\x18\x08 \x01(\t\x12\x11\n\trank_name\x18\t \x01(\t\"{\n\x07Module1\x12\x11\n\tgame_name\x18\x01 \x01(\t\x12\x11\n\tgame_icon\x18\x02 \x01(\t\x12\x1c\n\x14\x64\x65veloper_input_name\x18\x03 \x01(\t\x12,\n\x08tag_list\x18\x04 \x03(\x0b\x32\x1a.bilibili.ad.v1.AndroidTag\"Q\n\x07Module3\x12\x0f\n\x07\x64isplay\x18\x01 \x01(\x08\x12\x35\n\x0equality_params\x18\x03 \x03(\x0b\x32\x1d.bilibili.ad.v1.QualityParmas\"i\n\x07Module4\x12\x0f\n\x07\x64isplay\x18\x01 \x01(\x08\x12\x10\n\x08gift_num\x18\x02 \x01(\x05\x12\x11\n\tgift_name\x18\x03 \x01(\t\x12\x15\n\rgift_icon_num\x18\x04 \x01(\x05\x12\x11\n\ticon_urls\x18\x05 \x03(\t\"0\n\x07Module5\x12\x0f\n\x07\x64isplay\x18\x01 \x01(\x08\x12\x14\n\x0cgame_summary\x18\x02 \x01(\t\"-\n\x07Module6\x12\x0f\n\x07\x64isplay\x18\x01 \x01(\x08\x12\x11\n\tgame_desc\x18\x02 \x01(\t\"M\n\x07Module7\x12\x0f\n\x07\x64isplay\x18\x01 \x01(\x08\x12\x31\n\x0cscreen_shots\x18\x02 \x03(\x0b\x32\x1b.bilibili.ad.v1.ScreenShots\",\n\x07Module8\x12\x0f\n\x07\x64isplay\x18\x01 \x01(\x08\x12\x10\n\x08tag_list\x18\x02 \x03(\t\"4\n\x07Module9\x12\x0f\n\x07\x64isplay\x18\x01 \x01(\x08\x12\x18\n\x10\x64\x65v_introduction\x18\x02 \x01(\t\"2\n\x08Module10\x12\x0f\n\x07\x64isplay\x18\x01 \x01(\x08\x12\x15\n\rlatest_update\x18\x02 \x01(\t\"Y\n\x08Module11\x12\x0f\n\x07\x64isplay\x18\x01 \x01(\x08\x12\x18\n\x10star_number_list\x18\x02 \x03(\x05\x12\x13\n\x0b\x63omment_str\x18\x03 \x01(\t\x12\r\n\x05grade\x18\x04 \x01(\x01\"y\n\x08Module12\x12\x0f\n\x07\x64isplay\x18\x01 \x01(\x08\x12-\n\x0c\x63omment_list\x18\x02 \x03(\x0b\x32\x17.bilibili.ad.v1.Comment\x12\x13\n\x0b\x63omment_num\x18\x03 \x01(\t\x12\x18\n\x10show_all_comment\x18\x04 \x01(\x08\"\xc8\x01\n\x08Module13\x12\x10\n\x08pkg_size\x18\x01 \x01(\x03\x12\x18\n\x10\x63ustomer_service\x18\x02 \x01(\t\x12\x0f\n\x07website\x18\x03 \x01(\t\x12\x11\n\tauthority\x18\x04 \x01(\t\x12\x0f\n\x07privacy\x18\x05 \x01(\t\x12\x16\n\x0e\x64\x65veloper_name\x18\x06 \x01(\t\x12\x13\n\x0bupdate_time\x18\x07 \x01(\t\x12\x14\n\x0cgame_version\x18\x08 \x01(\t\x12\x18\n\x10\x61ndroid_pkg_name\x18\t \x01(\t\"H\n\x08Module14\x12+\n\x0breward_list\x18\x01 \x03(\x0b\x32\x16.bilibili.ad.v1.Reward\x12\x0f\n\x07\x64isplay\x18\x02 \x01(\x08\"3\n\x10NotClickableArea\x12\t\n\x01x\x18\x01 \x01(\x05\x12\t\n\x01y\x18\x02 \x01(\x05\x12\t\n\x01z\x18\x03 \x01(\x05\"b\n\x0bQualityInfo\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\r\n\x05is_bg\x18\x03 \x01(\x08\x12\x10\n\x08\x62g_color\x18\x04 \x01(\t\x12\x16\n\x0e\x62g_color_night\x18\x05 \x01(\t\"p\n\rQualityParmas\x12\x12\n\nfirst_line\x18\x01 \x01(\t\x12\x13\n\x0bsecond_line\x18\x02 \x01(\t\x12\r\n\x05grade\x18\x03 \x01(\x01\x12\x11\n\trank_icon\x18\x04 \x01(\t\x12\x14\n\x0cquality_type\x18\x05 \x01(\x05\"S\n\x06Reward\x12\r\n\x05level\x18\x01 \x01(\x05\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t\x12\x0b\n\x03pic\x18\x04 \x01(\t\x12\r\n\x05reach\x18\x05 \x01(\x08\"F\n\x0bScreenShots\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x0e\n\x06height\x18\x02 \x01(\x05\x12\r\n\x05width\x18\x03 \x01(\x05\x12\x0b\n\x03seq\x18\x04 \x01(\x05\"\x91\x02\n\x10SourceContentDto\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12\x11\n\tsource_id\x18\x02 \x01(\x05\x12\x13\n\x0bresource_id\x18\x03 \x01(\x05\x12\x11\n\tis_ad_loc\x18\x04 \x01(\x08\x12\x30\n\x0bserver_type\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\x11\n\tclient_ip\x18\x06 \x01(\t\x12/\n\ncard_index\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\r\n\x05index\x18\x08 \x01(\x05\x12)\n\nad_content\x18\t \x01(\x0b\x32\x15.bilibili.ad.v1.AdDto\"\xe4\x01\n\rSubCardModule\x12\x14\n\x0csubcard_type\x18\x01 \x01(\t\x12\x0c\n\x04icon\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\x12\x12\n\nrank_stars\x18\x04 \x01(\t\x12\x15\n\ramount_number\x18\x05 \x01(\t\x12\x0e\n\x06\x61vatar\x18\x06 \x01(\t\x12\r\n\x05title\x18\x07 \x01(\t\x12+\n\x06\x62utton\x18\x08 \x01(\x0b\x32\x1b.bilibili.ad.v1.AdButtonDto\x12*\n\ttag_infos\x18\t \x03(\x0b\x32\x17.bilibili.ad.v1.TagInfo\"\x8b\x06\n\x0cTab2ExtraDto\x12\x11\n\tcover_url\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\x12+\n\x06\x62utton\x18\x05 \x01(\x0b\x32\x1b.bilibili.ad.v1.AdButtonDto\x12\x1c\n\x14\x61uto_animate_time_ms\x18\x06 \x01(\x05\x12\x14\n\x0c\x65nable_click\x18\x07 \x01(\x08\x12\x11\n\tpanel_url\x18\x08 \x01(\t\x12\x39\n\x12\x64ownload_whitelist\x18\t \x03(\x0b\x32\x1d.bilibili.ad.v1.AppPackageDto\x12\x16\n\x0eopen_whitelist\x18\n \x03(\t\x12\x15\n\ruse_ad_web_v2\x18\x0b \x01(\x08\x12\"\n\x1a\x65nable_store_direct_launch\x18\x0c \x01(\x08\x12\x12\n\nsales_type\x18\r \x01(\x05\x12\"\n\x1alandingpage_download_style\x18\x0f \x01(\x05\x12\x19\n\x11\x61ppstore_priority\x18\x10 \x01(\x05\x12\x14\n\x0c\x61ppstore_url\x18\x11 \x01(\t\x12\x1b\n\x13\x61ppstore_delay_time\x18\x12 \x01(\x05\x12\x17\n\x0fpage_cover_type\x18\x13 \x01(\x05\x12\x16\n\x0epage_pull_type\x18\x14 \x01(\x05\x12\x41\n\x15\x61ndroid_game_page_res\x18\x15 \x01(\x0b\x32\".bilibili.ad.v1.AndroidGamePageRes\x12\x39\n\x11ios_game_page_res\x18\x16 \x01(\x0b\x32\x1e.bilibili.ad.v1.IosGamePageRes\x12\x37\n\x0c\x61\x64_tag_style\x18\x17 \x01(\x0b\x32!.bilibili.ad.v1.AdBusinessMarkDto\x12:\n\x0e\x66\x65\x65\x64\x62\x61\x63k_panel\x18\x18 \x01(\x0b\x32\".bilibili.ad.v1.AdFeedbackPanelDto\x12\r\n\x05\x61\x64_cb\x18\x19 \x01(\t\x12\x10\n\x08url_type\x18\x1a \x01(\x05\"\xa6\x03\n\x0bTabExtraDto\x12\x0f\n\x07tab_url\x18\x01 \x01(\t\x12\"\n\x1a\x65nable_store_direct_launch\x18\x02 \x01(\x05\x12\x19\n\x11store_callup_card\x18\x03 \x01(\x05\x12\x12\n\nsales_type\x18\x04 \x01(\x05\x12\x39\n\x12\x64ownload_whitelist\x18\x05 \x03(\x0b\x32\x1d.bilibili.ad.v1.AppPackageDto\x12\x18\n\x10special_industry\x18\x06 \x01(\x08\x12\x1d\n\x15special_industry_tips\x18\x07 \x01(\t\x12\x16\n\x0eopen_whitelist\x18\x08 \x03(\t\x12\"\n\x1alandingpage_download_style\x18\t \x01(\x05\x12\x19\n\x11\x61ppstore_priority\x18\n \x01(\x05\x12\x15\n\ruse_ad_web_v2\x18\x0b \x01(\x08\x12\x1e\n\x16\x65nable_download_dialog\x18\x0c \x01(\x08\x12\x14\n\x0c\x61ppstore_url\x18\r \x01(\t\x12\x1b\n\x13\x61ppstore_delay_time\x18\x0e \x01(\x05\"X\n\nTabInfoDto\x12\x10\n\x08tab_name\x18\x01 \x01(\t\x12#\n\x05\x65xtra\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x13\n\x0btab_version\x18\x03 \x01(\x05\"\xaf\x01\n\x07TagInfo\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x12\n\ntext_color\x18\x02 \x01(\t\x12\x18\n\x10text_color_night\x18\x03 \x01(\t\x12\x10\n\x08\x62g_color\x18\x04 \x01(\t\x12\x16\n\x0e\x62g_color_night\x18\x05 \x01(\t\x12\x14\n\x0c\x62order_color\x18\x06 \x01(\t\x12\x1a\n\x12\x62order_color_night\x18\x07 \x01(\t\x12\x0c\n\x04type\x18\x08 \x01(\t\";\n\rWxProgramInfo\x12\x0e\n\x06org_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.ad.v1.ad_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ADAUTOPLAYVIDEODTO._serialized_start=103
  _ADAUTOPLAYVIDEODTO._serialized_end=374
  _ADBUSINESSMARKDTO._serialized_start=377
  _ADBUSINESSMARKDTO._serialized_end=643
  _ADBUTTONDTO._serialized_start=646
  _ADBUTTONDTO._serialized_end=850
  _ADCARDDTO._serialized_start=853
  _ADCARDDTO._serialized_end=2628
  _ADCONTENTEXTRADTO._serialized_start=2631
  _ADCONTENTEXTRADTO._serialized_end=3836
  _ADCOVERDTO._serialized_start=3838
  _ADCOVERDTO._serialized_end=3959
  _ADDTO._serialized_start=3962
  _ADDTO._serialized_end=4229
  _ADFEEDBACKPANELDTO._serialized_start=4232
  _ADFEEDBACKPANELDTO._serialized_end=4412
  _ADFEEDBACKPANELMODULEDTO._serialized_start=4415
  _ADFEEDBACKPANELMODULEDTO._serialized_end=4614
  _ADGOODDTO._serialized_start=4616
  _ADGOODDTO._serialized_end=4694
  _ADOGVEPDTO._serialized_start=4696
  _ADOGVEPDTO._serialized_end=4745
  _ADSCONTROLDTO._serialized_start=4747
  _ADSCONTROLDTO._serialized_end=4836
  _ADSECONDFEEDBACKPANELDTO._serialized_start=4838
  _ADSECONDFEEDBACKPANELDTO._serialized_end=4897
  _ADSHAREINFODTO._serialized_start=4899
  _ADSHAREINFODTO._serialized_end=4967
  _ADVERDTO._serialized_start=4970
  _ADVERDTO._serialized_end=5102
  _ANDROIDGAMEPAGERES._serialized_start=5105
  _ANDROIDGAMEPAGERES._serialized_end=5727
  _ANDROIDTAG._serialized_start=5729
  _ANDROIDTAG._serialized_end=5769
  _APPPACKAGEDTO._serialized_start=5772
  _APPPACKAGEDTO._serialized_end=6035
  _BULLETIN._serialized_start=6037
  _BULLETIN._serialized_end=6079
  _COMMENT._serialized_start=6082
  _COMMENT._serialized_end=6241
  _CREATIVEDTO._serialized_start=6244
  _CREATIVEDTO._serialized_end=6503
  _CUSTOMPLAYURL._serialized_start=6505
  _CUSTOMPLAYURL._serialized_end=6553
  _FORWARDREPLY._serialized_start=6556
  _FORWARDREPLY._serialized_end=6761
  _GIFT._serialized_start=6763
  _GIFT._serialized_end=6830
  _IOSGAMEPAGERES._serialized_start=6833
  _IOSGAMEPAGERES._serialized_end=7032
  _MODULE1._serialized_start=7034
  _MODULE1._serialized_end=7157
  _MODULE3._serialized_start=7159
  _MODULE3._serialized_end=7240
  _MODULE4._serialized_start=7242
  _MODULE4._serialized_end=7347
  _MODULE5._serialized_start=7349
  _MODULE5._serialized_end=7397
  _MODULE6._serialized_start=7399
  _MODULE6._serialized_end=7444
  _MODULE7._serialized_start=7446
  _MODULE7._serialized_end=7523
  _MODULE8._serialized_start=7525
  _MODULE8._serialized_end=7569
  _MODULE9._serialized_start=7571
  _MODULE9._serialized_end=7623
  _MODULE10._serialized_start=7625
  _MODULE10._serialized_end=7675
  _MODULE11._serialized_start=7677
  _MODULE11._serialized_end=7766
  _MODULE12._serialized_start=7768
  _MODULE12._serialized_end=7889
  _MODULE13._serialized_start=7892
  _MODULE13._serialized_end=8092
  _MODULE14._serialized_start=8094
  _MODULE14._serialized_end=8166
  _NOTCLICKABLEAREA._serialized_start=8168
  _NOTCLICKABLEAREA._serialized_end=8219
  _QUALITYINFO._serialized_start=8221
  _QUALITYINFO._serialized_end=8319
  _QUALITYPARMAS._serialized_start=8321
  _QUALITYPARMAS._serialized_end=8433
  _REWARD._serialized_start=8435
  _REWARD._serialized_end=8518
  _SCREENSHOTS._serialized_start=8520
  _SCREENSHOTS._serialized_end=8590
  _SOURCECONTENTDTO._serialized_start=8593
  _SOURCECONTENTDTO._serialized_end=8866
  _SUBCARDMODULE._serialized_start=8869
  _SUBCARDMODULE._serialized_end=9097
  _TAB2EXTRADTO._serialized_start=9100
  _TAB2EXTRADTO._serialized_end=9879
  _TABEXTRADTO._serialized_start=9882
  _TABEXTRADTO._serialized_end=10304
  _TABINFODTO._serialized_start=10306
  _TABINFODTO._serialized_end=10394
  _TAGINFO._serialized_start=10397
  _TAGINFO._serialized_end=10572
  _WXPROGRAMINFO._serialized_start=10574
  _WXPROGRAMINFO._serialized_end=10633
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/api/probe/v1/probe.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!bilibili/api/probe/v1/probe.proto\x12\x15\x62ilibili.api.probe.v1\"\x0b\n\tCodeReply\"\x17\n\x07\x43odeReq\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x03\"J\n\x14\x44ynamicMessageUpdate\x12\x32\n\x04\x62ody\x18\x01 \x01(\x0b\x32$.bilibili.api.probe.v1.SimpleMessage\"\xd8\x03\n\x08\x45mbedded\x12\x10\n\x08\x62ool_val\x18\x01 \x01(\x08\x12\x11\n\tint32_val\x18\x02 \x01(\x05\x12\x11\n\tint64_val\x18\x03 \x01(\x03\x12\x11\n\tfloat_val\x18\x04 \x01(\x02\x12\x12\n\ndouble_val\x18\x05 \x01(\x01\x12\x12\n\nstring_val\x18\x06 \x01(\t\x12\x1a\n\x12repeated_int32_val\x18\x08 \x03(\x05\x12\x1b\n\x13repeated_string_val\x18\x0c \x03(\t\x12I\n\x0emap_string_val\x18\r \x03(\x0b\x32\x31.bilibili.api.probe.v1.Embedded.MapStringValEntry\x12G\n\rmap_error_val\x18\x0e \x03(\x0b\x32\x30.bilibili.api.probe.v1.Embedded.MapErrorValEntry\x1a\x33\n\x11MapStringValEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1aW\n\x10MapErrorValEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32#.bilibili.api.probe.v1.ErrorMessage:\x02\x38\x01\"=\n\x0c\x45rrorMessage\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x03\x12\x0e\n\x06reason\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\"0\n\nProbeReply\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\x03\"&\n\x08ProbeReq\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\r\n\x05\x62uvid\x18\x02 \x01(\t\"H\n\x10ProbeStreamReply\x12\x10\n\x08sequence\x18\x01 \x01(\x03\x12\x11\n\ttimestamp\x18\x02 \x01(\x03\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t\"/\n\x0eProbeStreamReq\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x10\n\x08sequence\x18\x02 \x01(\x03\"#\n\rProbeSubReply\x12\x12\n\nmessage_id\x18\x01 \x01(\x03\"\x1c\n\x0bProbeSubReq\x12\r\n\x05\x62uvid\x18\x01 \x01(\x03\"w\n\rSimpleMessage\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0b\n\x03num\x18\x02 \x01(\x03\x12\x0c\n\x04lang\x18\x03 \x01(\t\x12\x0c\n\x04\x63\x61te\x18\x04 \x01(\x05\x12\x31\n\x08\x65mbedded\x18\x05 \x01(\x0b\x32\x1f.bilibili.api.probe.v1.Embedded*\\\n\x08\x43\x61tegory\x12\x18\n\x14\x43\x41TEGORY_UNSPECIFIED\x10\x00\x12\x10\n\x0c\x43\x41TEGORY_ONE\x10\x01\x12\x10\n\x0c\x43\x41TEGORY_TWO\x10\x02\x12\x12\n\x0e\x43\x41TEGORY_THREE\x10\x03*A\n\x0b\x45rrorReason\x12\x15\n\x11PROBE_UNSPECIFIED\x10\x00\x12\x1b\n\x17PROBE_CATEGORY_NOTFOUND\x10\x01\x32\xd7\x02\n\x05Probe\x12L\n\x08TestCode\x12\x1e.bilibili.api.probe.v1.CodeReq\x1a .bilibili.api.probe.v1.CodeReply\x12M\n\x07TestReq\x12\x1f.bilibili.api.probe.v1.ProbeReq\x1a!.bilibili.api.probe.v1.ProbeReply\x12\\\n\nTestStream\x12%.bilibili.api.probe.v1.ProbeStreamReq\x1a\'.bilibili.api.probe.v1.ProbeStreamReply\x12S\n\x07TestSub\x12\".bilibili.api.probe.v1.ProbeSubReq\x1a$.bilibili.api.probe.v1.ProbeSubReplyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.api.probe.v1.probe_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _EMBEDDED_MAPSTRINGVALENTRY._options = None
  _EMBEDDED_MAPSTRINGVALENTRY._serialized_options = b'8\001'
  _EMBEDDED_MAPERRORVALENTRY._options = None
  _EMBEDDED_MAPERRORVALENTRY._serialized_options = b'8\001'
  _CATEGORY._serialized_start=1113
  _CATEGORY._serialized_end=1205
  _ERRORREASON._serialized_start=1207
  _ERRORREASON._serialized_end=1272
  _CODEREPLY._serialized_start=60
  _CODEREPLY._serialized_end=71
  _CODEREQ._serialized_start=73
  _CODEREQ._serialized_end=96
  _DYNAMICMESSAGEUPDATE._serialized_start=98
  _DYNAMICMESSAGEUPDATE._serialized_end=172
  _EMBEDDED._serialized_start=175
  _EMBEDDED._serialized_end=647
  _EMBEDDED_MAPSTRINGVALENTRY._serialized_start=507
  _EMBEDDED_MAPSTRINGVALENTRY._serialized_end=558
  _EMBEDDED_MAPERRORVALENTRY._serialized_start=560
  _EMBEDDED_MAPERRORVALENTRY._serialized_end=647
  _ERRORMESSAGE._serialized_start=649
  _ERRORMESSAGE._serialized_end=710
  _PROBEREPLY._serialized_start=712
  _PROBEREPLY._serialized_end=760
  _PROBEREQ._serialized_start=762
  _PROBEREQ._serialized_end=800
  _PROBESTREAMREPLY._serialized_start=802
  _PROBESTREAMREPLY._serialized_end=874
  _PROBESTREAMREQ._serialized_start=876
  _PROBESTREAMREQ._serialized_end=923
  _PROBESUBREPLY._serialized_start=925
  _PROBESUBREPLY._serialized_end=960
  _PROBESUBREQ._serialized_start=962
  _PROBESUBREQ._serialized_end=990
  _SIMPLEMESSAGE._serialized_start=992
  _SIMPLEMESSAGE._serialized_end=1111
  _PROBE._serialized_start=1275
  _PROBE._serialized_end=1618
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class RuleInfo(google.protobuf.message.Message):
    """免流规则信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TF_FIELD_NUMBER: builtins.int
    M_FIELD_NUMBER: builtins.int
    A_FIELD_NUMBER: builtins.int
    P_FIELD_NUMBER: builtins.int
    A_BACKUP_FIELD_NUMBER: builtins.int
    tf: builtins.bool
    """是否支持免流"""
    m: builtins.str
    """操作模式
    break:无 replace:替换 proxy:代理
    """
    a: builtins.str
    """操作参数"""
    p: builtins.str
    """匹配目标正则"""
    @property
    def a_backup(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """"""
    def __init__(
        self,
        *,
        tf: builtins.bool = ...,
        m: builtins.str = ...,
        a: builtins.str = ...,
        p: builtins.str = ...,
        a_backup: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["a", b"a", "a_backup", b"a_backup", "m", b"m", "p", b"p", "tf", b"tf"]) -> None: ...

global___RuleInfo = RuleInfo

@typing_extensions.final
class RuleRequest(google.protobuf.message.Message):
    """获取免流规则信息-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RuleRequest = RuleRequest

@typing_extensions.final
class RulesInfo(google.protobuf.message.Message):
    """免流规则信息组"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RULESINFO_FIELD_NUMBER: builtins.int
    @property
    def rulesInfo(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RuleInfo]:
        """免流规则信息"""
    def __init__(
        self,
        *,
        rulesInfo: collections.abc.Iterable[global___RuleInfo] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["rulesInfo", b"rulesInfo"]) -> None: ...

global___RulesInfo = RulesInfo

@typing_extensions.final
class RulesReply(google.protobuf.message.Message):
    """获取免流规则信息-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class RulesInfoEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___RulesInfo: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___RulesInfo | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RULESINFO_FIELD_NUMBER: builtins.int
    HASH_VALUE_FIELD_NUMBER: builtins.int
    @property
    def rulesInfo(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___RulesInfo]:
        """各ISP的免流规则信息组
        ISP如: cu ct cm
        """
    hash_value: builtins.str
    """"""
    def __init__(
        self,
        *,
        rulesInfo: collections.abc.Mapping[builtins.str, global___RulesInfo] | None = ...,
        hash_value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["hash_value", b"hash_value", "rulesInfo", b"rulesInfo"]) -> None: ...

global___RulesReply = RulesReply



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/polymer/list/list.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n bilibili/polymer/list/list.proto\x12\x15\x62ilibili.polymer.list\"#\n\x11\x43heckAccountReply\x12\x0e\n\x06is_new\x18\x01 \x01(\x08\"/\n\x0f\x43heckAccountReq\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x0f\n\x07periods\x18\x02 \x01(\t\":\n\x0f\x46\x61voriteTabItem\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\"I\n\x10\x46\x61voriteTabReply\x12\x35\n\x05items\x18\x01 \x03(\x0b\x32&.bilibili.polymer.list.FavoriteTabItem\"\x10\n\x0e\x46\x61voriteTabReq2\xc7\x01\n\x04List\x12]\n\x0b\x46\x61voriteTab\x12%.bilibili.polymer.list.FavoriteTabReq\x1a\'.bilibili.polymer.list.FavoriteTabReply\x12`\n\x0c\x43heckAccount\x12&.bilibili.polymer.list.CheckAccountReq\x1a(.bilibili.polymer.list.CheckAccountReplyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.polymer.list.list_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CHECKACCOUNTREPLY._serialized_start=59
  _CHECKACCOUNTREPLY._serialized_end=94
  _CHECKACCOUNTREQ._serialized_start=96
  _CHECKACCOUNTREQ._serialized_end=143
  _FAVORITETABITEM._serialized_start=145
  _FAVORITETABITEM._serialized_end=203
  _FAVORITETABREPLY._serialized_start=205
  _FAVORITETABREPLY._serialized_end=278
  _FAVORITETABREQ._serialized_start=280
  _FAVORITETABREQ._serialized_end=296
  _LIST._serialized_start=299
  _LIST._serialized_end=498
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _CompressType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CompressTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CompressType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    Unzip: _CompressType.ValueType  # 0
    """unzip"""
    Original: _CompressType.ValueType  # 1
    """不操作"""

class CompressType(_CompressType, metaclass=_CompressTypeEnumTypeWrapper):
    """"""

Unzip: CompressType.ValueType  # 0
"""unzip"""
Original: CompressType.ValueType  # 1
"""不操作"""
global___CompressType = CompressType

class _EnvType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _EnvTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_EnvType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    Unknown: _EnvType.ValueType  # 0
    """"""
    Release: _EnvType.ValueType  # 1
    """"""
    Test: _EnvType.ValueType  # 2
    """"""

class EnvType(_EnvType, metaclass=_EnvTypeEnumTypeWrapper):
    """"""

Unknown: EnvType.ValueType  # 0
""""""
Release: EnvType.ValueType  # 1
""""""
Test: EnvType.ValueType  # 2
""""""
global___EnvType = EnvType

class _IncrementType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _IncrementTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_IncrementType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    Total: _IncrementType.ValueType  # 0
    """全量包"""
    Incremental: _IncrementType.ValueType  # 1
    """增量包"""

class IncrementType(_IncrementType, metaclass=_IncrementTypeEnumTypeWrapper):
    """"""

Total: IncrementType.ValueType  # 0
"""全量包"""
Incremental: IncrementType.ValueType  # 1
"""增量包"""
global___IncrementType = IncrementType

class _LevelType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _LevelTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_LevelType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    Undefined: _LevelType.ValueType  # 0
    """"""
    High: _LevelType.ValueType  # 1
    """高 需立即下载"""
    Middle: _LevelType.ValueType  # 2
    """中 可以延迟下载"""
    Low: _LevelType.ValueType  # 3
    """低 仅在业务方使用到时由业务方手动进行下载"""

class LevelType(_LevelType, metaclass=_LevelTypeEnumTypeWrapper):
    """"""

Undefined: LevelType.ValueType  # 0
""""""
High: LevelType.ValueType  # 1
"""高 需立即下载"""
Middle: LevelType.ValueType  # 2
"""中 可以延迟下载"""
Low: LevelType.ValueType  # 3
"""低 仅在业务方使用到时由业务方手动进行下载"""
global___LevelType = LevelType

@typing_extensions.final
class ListReply(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENV_FIELD_NUMBER: builtins.int
    POOLS_FIELD_NUMBER: builtins.int
    LIST_VERSION_FIELD_NUMBER: builtins.int
    env: builtins.str
    """"""
    @property
    def pools(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PoolReply]:
        """"""
    list_version: builtins.int
    """"""
    def __init__(
        self,
        *,
        env: builtins.str = ...,
        pools: collections.abc.Iterable[global___PoolReply] | None = ...,
        list_version: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["env", b"env", "list_version", b"list_version", "pools", b"pools"]) -> None: ...

global___ListReply = ListReply

@typing_extensions.final
class ListReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POOL_NAME_FIELD_NUMBER: builtins.int
    MODULE_NAME_FIELD_NUMBER: builtins.int
    VERSION_LIST_FIELD_NUMBER: builtins.int
    ENV_FIELD_NUMBER: builtins.int
    SYS_VER_FIELD_NUMBER: builtins.int
    SCALE_FIELD_NUMBER: builtins.int
    ARCH_FIELD_NUMBER: builtins.int
    LIST_VERSION_FIELD_NUMBER: builtins.int
    pool_name: builtins.str
    """"""
    module_name: builtins.str
    """"""
    @property
    def version_list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VersionListReq]:
        """"""
    env: global___EnvType.ValueType
    """"""
    sys_ver: builtins.int
    """"""
    scale: builtins.int
    """"""
    arch: builtins.int
    """"""
    list_version: builtins.int
    """"""
    def __init__(
        self,
        *,
        pool_name: builtins.str = ...,
        module_name: builtins.str = ...,
        version_list: collections.abc.Iterable[global___VersionListReq] | None = ...,
        env: global___EnvType.ValueType = ...,
        sys_ver: builtins.int = ...,
        scale: builtins.int = ...,
        arch: builtins.int = ...,
        list_version: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["arch", b"arch", "env", b"env", "list_version", b"list_version", "module_name", b"module_name", "pool_name", b"pool_name", "scale", b"scale", "sys_ver", b"sys_ver", "version_list", b"version_list"]) -> None: ...

global___ListReq = ListReq

@typing_extensions.final
class ModuleReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    MD5_FIELD_NUMBER: builtins.int
    TOTAL_MD5_FIELD_NUMBER: builtins.int
    INCREMENT_FIELD_NUMBER: builtins.int
    IS_WIFI_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    FILENAME_FIELD_NUMBER: builtins.int
    FILE_TYPE_FIELD_NUMBER: builtins.int
    FILE_SIZE_FIELD_NUMBER: builtins.int
    COMPRESS_FIELD_NUMBER: builtins.int
    PUBLISH_TIME_FIELD_NUMBER: builtins.int
    POOL_ID_FIELD_NUMBER: builtins.int
    MODULE_ID_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    FILE_ID_FIELD_NUMBER: builtins.int
    ZIP_CHECK_FIELD_NUMBER: builtins.int
    name: builtins.str
    """"""
    version: builtins.int
    """"""
    url: builtins.str
    """"""
    md5: builtins.str
    """"""
    total_md5: builtins.str
    """"""
    increment: global___IncrementType.ValueType
    """"""
    is_wifi: builtins.bool
    """"""
    level: global___LevelType.ValueType
    """"""
    filename: builtins.str
    """"""
    file_type: builtins.str
    """"""
    file_size: builtins.int
    """"""
    compress: global___CompressType.ValueType
    """"""
    publish_time: builtins.int
    """"""
    pool_id: builtins.int
    """上报使用"""
    module_id: builtins.int
    """"""
    version_id: builtins.int
    """"""
    file_id: builtins.int
    """"""
    zip_check: builtins.bool
    """"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        version: builtins.int = ...,
        url: builtins.str = ...,
        md5: builtins.str = ...,
        total_md5: builtins.str = ...,
        increment: global___IncrementType.ValueType = ...,
        is_wifi: builtins.bool = ...,
        level: global___LevelType.ValueType = ...,
        filename: builtins.str = ...,
        file_type: builtins.str = ...,
        file_size: builtins.int = ...,
        compress: global___CompressType.ValueType = ...,
        publish_time: builtins.int = ...,
        pool_id: builtins.int = ...,
        module_id: builtins.int = ...,
        version_id: builtins.int = ...,
        file_id: builtins.int = ...,
        zip_check: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["compress", b"compress", "file_id", b"file_id", "file_size", b"file_size", "file_type", b"file_type", "filename", b"filename", "increment", b"increment", "is_wifi", b"is_wifi", "level", b"level", "md5", b"md5", "module_id", b"module_id", "name", b"name", "pool_id", b"pool_id", "publish_time", b"publish_time", "total_md5", b"total_md5", "url", b"url", "version", b"version", "version_id", b"version_id", "zip_check", b"zip_check"]) -> None: ...

global___ModuleReply = ModuleReply

@typing_extensions.final
class PoolReply(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    MODULES_FIELD_NUMBER: builtins.int
    name: builtins.str
    """"""
    @property
    def modules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ModuleReply]:
        """"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        modules: collections.abc.Iterable[global___ModuleReply] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["modules", b"modules", "name", b"name"]) -> None: ...

global___PoolReply = PoolReply

@typing_extensions.final
class VersionListReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POOL_NAME_FIELD_NUMBER: builtins.int
    VERSIONS_FIELD_NUMBER: builtins.int
    pool_name: builtins.str
    """"""
    @property
    def versions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VersionReq]:
        """"""
    def __init__(
        self,
        *,
        pool_name: builtins.str = ...,
        versions: collections.abc.Iterable[global___VersionReq] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pool_name", b"pool_name", "versions", b"versions"]) -> None: ...

global___VersionListReq = VersionListReq

@typing_extensions.final
class VersionReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODULE_NAME_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    module_name: builtins.str
    """"""
    version: builtins.int
    """"""
    def __init__(
        self,
        *,
        module_name: builtins.str = ...,
        version: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["module_name", b"module_name", "version", b"version"]) -> None: ...

global___VersionReq = VersionReq



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _AntiHarassmentLimit:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AntiHarassmentLimitEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AntiHarassmentLimit.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DefaultLimit: _AntiHarassmentLimit.ValueType  # 0
    """"""
    FollowLimit: _AntiHarassmentLimit.ValueType  # 1
    """"""
    ReFollowLimit: _AntiHarassmentLimit.ValueType  # 2
    """"""
    TwoWayFollow: _AntiHarassmentLimit.ValueType  # 3
    """"""
    AllLimit: _AntiHarassmentLimit.ValueType  # 4
    """"""

class AntiHarassmentLimit(_AntiHarassmentLimit, metaclass=_AntiHarassmentLimitEnumTypeWrapper):
    """"""

DefaultLimit: AntiHarassmentLimit.ValueType  # 0
""""""
FollowLimit: AntiHarassmentLimit.ValueType  # 1
""""""
ReFollowLimit: AntiHarassmentLimit.ValueType  # 2
""""""
TwoWayFollow: AntiHarassmentLimit.ValueType  # 3
""""""
AllLimit: AntiHarassmentLimit.ValueType  # 4
""""""
global___AntiHarassmentLimit = AntiHarassmentLimit

class _BizType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _BizTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_BizType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    InvalidBizType: _BizType.ValueType  # 0
    """"""
    Im: _BizType.ValueType  # 1
    """"""
    Dm: _BizType.ValueType  # 2
    """"""
    Reply: _BizType.ValueType  # 3
    """"""
    ReplyMe: _BizType.ValueType  # 4
    """"""
    LikeMe: _BizType.ValueType  # 5
    """"""
    AtMe: _BizType.ValueType  # 6
    """"""

class BizType(_BizType, metaclass=_BizTypeEnumTypeWrapper):
    """"""

InvalidBizType: BizType.ValueType  # 0
""""""
Im: BizType.ValueType  # 1
""""""
Dm: BizType.ValueType  # 2
""""""
Reply: BizType.ValueType  # 3
""""""
ReplyMe: BizType.ValueType  # 4
""""""
LikeMe: BizType.ValueType  # 5
""""""
AtMe: BizType.ValueType  # 6
""""""
global___BizType = BizType

@typing_extensions.final
class AntiHarassmentInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIMIT_FIELD_NUMBER: builtins.int
    FOLLOW_TIME_LIMIT_SECOND_FIELD_NUMBER: builtins.int
    EXPIRE_TIME_FIELD_NUMBER: builtins.int
    limit: builtins.int
    """"""
    follow_time_limit_second: builtins.int
    """"""
    expire_time: builtins.int
    """"""
    def __init__(
        self,
        *,
        limit: builtins.int = ...,
        follow_time_limit_second: builtins.int = ...,
        expire_time: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["expire_time", b"expire_time", "follow_time_limit_second", b"follow_time_limit_second", "limit", b"limit"]) -> None: ...

global___AntiHarassmentInfo = AntiHarassmentInfo

@typing_extensions.final
class AntiHarassmentSetting(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    AUTO_LIMIT_FIELD_NUMBER: builtins.int
    IM_FIELD_NUMBER: builtins.int
    REPLY_FIELD_NUMBER: builtins.int
    DM_FIELD_NUMBER: builtins.int
    REPLY_ME_FIELD_NUMBER: builtins.int
    LIKE_ME_FIELD_NUMBER: builtins.int
    AT_ME_FIELD_NUMBER: builtins.int
    AUTO_LIMIT_EXPIRE_TIME_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""
    auto_limit: builtins.bool
    """"""
    @property
    def im(self) -> global___AntiHarassmentInfo:
        """"""
    @property
    def reply(self) -> global___AntiHarassmentInfo:
        """"""
    @property
    def dm(self) -> global___AntiHarassmentInfo:
        """"""
    @property
    def reply_me(self) -> global___AntiHarassmentInfo:
        """"""
    @property
    def like_me(self) -> global___AntiHarassmentInfo:
        """"""
    @property
    def at_me(self) -> global___AntiHarassmentInfo:
        """"""
    auto_limit_expire_time: builtins.int
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        auto_limit: builtins.bool = ...,
        im: global___AntiHarassmentInfo | None = ...,
        reply: global___AntiHarassmentInfo | None = ...,
        dm: global___AntiHarassmentInfo | None = ...,
        reply_me: global___AntiHarassmentInfo | None = ...,
        like_me: global___AntiHarassmentInfo | None = ...,
        at_me: global___AntiHarassmentInfo | None = ...,
        auto_limit_expire_time: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["at_me", b"at_me", "dm", b"dm", "im", b"im", "like_me", b"like_me", "reply", b"reply", "reply_me", b"reply_me"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["at_me", b"at_me", "auto_limit", b"auto_limit", "auto_limit_expire_time", b"auto_limit_expire_time", "dm", b"dm", "im", b"im", "like_me", b"like_me", "mid", b"mid", "reply", b"reply", "reply_me", b"reply_me"]) -> None: ...

global___AntiHarassmentSetting = AntiHarassmentSetting

@typing_extensions.final
class LoadAntiHarassmentSettingsReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BIZ_TYPE_FIELD_NUMBER: builtins.int
    RECV_MID_FIELD_NUMBER: builtins.int
    SEND_MID_FIELD_NUMBER: builtins.int
    biz_type: builtins.int
    """"""
    recv_mid: builtins.int
    """"""
    send_mid: builtins.int
    """"""
    def __init__(
        self,
        *,
        biz_type: builtins.int = ...,
        recv_mid: builtins.int = ...,
        send_mid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["biz_type", b"biz_type", "recv_mid", b"recv_mid", "send_mid", b"send_mid"]) -> None: ...

global___LoadAntiHarassmentSettingsReq = LoadAntiHarassmentSettingsReq

@typing_extensions.final
class LoadAntiHarassmentSettingsRsp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ANTI_HARASSMENT_RET_FIELD_NUMBER: builtins.int
    ANTI_HARASSMENT_SETTING_FIELD_NUMBER: builtins.int
    SHOW_WINDOW_FIELD_NUMBER: builtins.int
    anti_harassment_ret: builtins.bool
    """"""
    @property
    def anti_harassment_setting(self) -> global___AntiHarassmentSetting:
        """"""
    show_window: builtins.int
    """"""
    def __init__(
        self,
        *,
        anti_harassment_ret: builtins.bool = ...,
        anti_harassment_setting: global___AntiHarassmentSetting | None = ...,
        show_window: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["anti_harassment_setting", b"anti_harassment_setting"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["anti_harassment_ret", b"anti_harassment_ret", "anti_harassment_setting", b"anti_harassment_setting", "show_window", b"show_window"]) -> None: ...

global___LoadAntiHarassmentSettingsRsp = LoadAntiHarassmentSettingsRsp

@typing_extensions.final
class StoreAntiHarassmentSettingsReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BIZ_TYPE_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    ANTI_HARASSMENT_SETTING_FIELD_NUMBER: builtins.int
    biz_type: builtins.int
    """"""
    mid: builtins.int
    """"""
    @property
    def anti_harassment_setting(self) -> global___AntiHarassmentSetting:
        """"""
    def __init__(
        self,
        *,
        biz_type: builtins.int = ...,
        mid: builtins.int = ...,
        anti_harassment_setting: global___AntiHarassmentSetting | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["anti_harassment_setting", b"anti_harassment_setting"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["anti_harassment_setting", b"anti_harassment_setting", "biz_type", b"biz_type", "mid", b"mid"]) -> None: ...

global___StoreAntiHarassmentSettingsReq = StoreAntiHarassmentSettingsReq

@typing_extensions.final
class StoreAntiHarassmentSettingsRsp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StoreAntiHarassmentSettingsRsp = StoreAntiHarassmentSettingsRsp
